# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class ListJobRunsRequest(DaraModel):
    def __init__(
        self,
        application_configs: str = None,
        creator: str = None,
        end_time: main_models.ListJobRunsRequestEndTime = None,
        is_workflow: str = None,
        job_run_deployment_id: str = None,
        job_run_id: str = None,
        max_results: int = None,
        min_duration: int = None,
        name: str = None,
        next_token: str = None,
        region_id: str = None,
        resource_queue_id: str = None,
        runtime_configs: str = None,
        start_time: main_models.ListJobRunsRequestStartTime = None,
        states: List[str] = None,
        tags: List[main_models.ListJobRunsRequestTags] = None,
    ):
        self.application_configs = application_configs
        # The ID of the user who created the job.
        self.creator = creator
        # The range of end time.
        self.end_time = end_time
        self.is_workflow = is_workflow
        # The job run ID.
        self.job_run_deployment_id = job_run_deployment_id
        # The job ID.
        self.job_run_id = job_run_id
        # The maximum number of entries to return.
        self.max_results = max_results
        # The minimum running duration of the job. Unit: ms.
        self.min_duration = min_duration
        # The job name.
        self.name = name
        # The pagination token that is used in the request to retrieve a new page of results.
        self.next_token = next_token
        # The region ID.
        self.region_id = region_id
        # The name of the resource queue on which the Spark jobs run.
        self.resource_queue_id = resource_queue_id
        self.runtime_configs = runtime_configs
        # The range of start time.
        self.start_time = start_time
        # The job states.
        self.states = states
        # The tags of the job.
        self.tags = tags

    def validate(self):
        if self.end_time:
            self.end_time.validate()
        if self.start_time:
            self.start_time.validate()
        if self.tags:
            for v1 in self.tags:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.application_configs is not None:
            result['applicationConfigs'] = self.application_configs

        if self.creator is not None:
            result['creator'] = self.creator

        if self.end_time is not None:
            result['endTime'] = self.end_time.to_map()

        if self.is_workflow is not None:
            result['isWorkflow'] = self.is_workflow

        if self.job_run_deployment_id is not None:
            result['jobRunDeploymentId'] = self.job_run_deployment_id

        if self.job_run_id is not None:
            result['jobRunId'] = self.job_run_id

        if self.max_results is not None:
            result['maxResults'] = self.max_results

        if self.min_duration is not None:
            result['minDuration'] = self.min_duration

        if self.name is not None:
            result['name'] = self.name

        if self.next_token is not None:
            result['nextToken'] = self.next_token

        if self.region_id is not None:
            result['regionId'] = self.region_id

        if self.resource_queue_id is not None:
            result['resourceQueueId'] = self.resource_queue_id

        if self.runtime_configs is not None:
            result['runtimeConfigs'] = self.runtime_configs

        if self.start_time is not None:
            result['startTime'] = self.start_time.to_map()

        if self.states is not None:
            result['states'] = self.states

        result['tags'] = []
        if self.tags is not None:
            for k1 in self.tags:
                result['tags'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('applicationConfigs') is not None:
            self.application_configs = m.get('applicationConfigs')

        if m.get('creator') is not None:
            self.creator = m.get('creator')

        if m.get('endTime') is not None:
            temp_model = main_models.ListJobRunsRequestEndTime()
            self.end_time = temp_model.from_map(m.get('endTime'))

        if m.get('isWorkflow') is not None:
            self.is_workflow = m.get('isWorkflow')

        if m.get('jobRunDeploymentId') is not None:
            self.job_run_deployment_id = m.get('jobRunDeploymentId')

        if m.get('jobRunId') is not None:
            self.job_run_id = m.get('jobRunId')

        if m.get('maxResults') is not None:
            self.max_results = m.get('maxResults')

        if m.get('minDuration') is not None:
            self.min_duration = m.get('minDuration')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('nextToken') is not None:
            self.next_token = m.get('nextToken')

        if m.get('regionId') is not None:
            self.region_id = m.get('regionId')

        if m.get('resourceQueueId') is not None:
            self.resource_queue_id = m.get('resourceQueueId')

        if m.get('runtimeConfigs') is not None:
            self.runtime_configs = m.get('runtimeConfigs')

        if m.get('startTime') is not None:
            temp_model = main_models.ListJobRunsRequestStartTime()
            self.start_time = temp_model.from_map(m.get('startTime'))

        if m.get('states') is not None:
            self.states = m.get('states')

        self.tags = []
        if m.get('tags') is not None:
            for k1 in m.get('tags'):
                temp_model = main_models.ListJobRunsRequestTags()
                self.tags.append(temp_model.from_map(k1))

        return self

class ListJobRunsRequestTags(DaraModel):
    def __init__(
        self,
        key: str = None,
        value: str = None,
    ):
        # The key of tag N.
        self.key = key
        # The value of tag N.
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.key is not None:
            result['key'] = self.key

        if self.value is not None:
            result['value'] = self.value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('key') is not None:
            self.key = m.get('key')

        if m.get('value') is not None:
            self.value = m.get('value')

        return self

class ListJobRunsRequestStartTime(DaraModel):
    def __init__(
        self,
        end_time: int = None,
        start_time: int = None,
    ):
        # The end of the start time range.
        self.end_time = end_time
        # The beginning of the start time range.
        self.start_time = start_time

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.end_time is not None:
            result['endTime'] = self.end_time

        if self.start_time is not None:
            result['startTime'] = self.start_time

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('endTime') is not None:
            self.end_time = m.get('endTime')

        if m.get('startTime') is not None:
            self.start_time = m.get('startTime')

        return self

class ListJobRunsRequestEndTime(DaraModel):
    def __init__(
        self,
        end_time: int = None,
        start_time: int = None,
    ):
        # The end of the end time range.
        self.end_time = end_time
        # The beginning of the end time range.
        self.start_time = start_time

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.end_time is not None:
            result['endTime'] = self.end_time

        if self.start_time is not None:
            result['startTime'] = self.start_time

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('endTime') is not None:
            self.end_time = m.get('endTime')

        if m.get('startTime') is not None:
            self.start_time = m.get('startTime')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class CancelJobRunResponseBody(DaraModel):
    def __init__(
        self,
        job_run_id: str = None,
        request_id: str = None,
    ):
        # The job ID.
        self.job_run_id = job_run_id
        # The request ID.
        self.request_id = request_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.job_run_id is not None:
            result['jobRunId'] = self.job_run_id

        if self.request_id is not None:
            result['requestId'] = self.request_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('jobRunId') is not None:
            self.job_run_id = m.get('jobRunId')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class CreateSessionClusterRequest(DaraModel):
    def __init__(
        self,
        application_configs: List[main_models.CreateSessionClusterRequestApplicationConfigs] = None,
        auto_start_configuration: main_models.CreateSessionClusterRequestAutoStartConfiguration = None,
        auto_stop_configuration: main_models.CreateSessionClusterRequestAutoStopConfiguration = None,
        client_token: str = None,
        display_release_version: str = None,
        env_id: str = None,
        fusion: bool = None,
        kind: str = None,
        name: str = None,
        public_endpoint_enabled: bool = None,
        queue_name: str = None,
        release_version: str = None,
        region_id: str = None,
    ):
        # The Spark configurations.
        self.application_configs = application_configs
        # Specifies whether to enable automatic startup.
        # 
        # *   true
        # *   false
        self.auto_start_configuration = auto_start_configuration
        # The automatic termination configuration.
        self.auto_stop_configuration = auto_stop_configuration
        self.client_token = client_token
        # The version of the Spark engine.
        self.display_release_version = display_release_version
        # The ID of the Python environment. This parameter takes effect only for notebook sessions.
        self.env_id = env_id
        # Specifies whether to enable Fusion engine for acceleration.
        self.fusion = fusion
        # The session type.
        # 
        # *   SQL
        # *   NOTEBOOK
        self.kind = kind
        # The name of the job.
        self.name = name
        self.public_endpoint_enabled = public_endpoint_enabled
        # The queue name.
        self.queue_name = queue_name
        # The version number of Spark.
        self.release_version = release_version
        # The region ID.
        self.region_id = region_id

    def validate(self):
        if self.application_configs:
            for v1 in self.application_configs:
                 if v1:
                    v1.validate()
        if self.auto_start_configuration:
            self.auto_start_configuration.validate()
        if self.auto_stop_configuration:
            self.auto_stop_configuration.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['applicationConfigs'] = []
        if self.application_configs is not None:
            for k1 in self.application_configs:
                result['applicationConfigs'].append(k1.to_map() if k1 else None)

        if self.auto_start_configuration is not None:
            result['autoStartConfiguration'] = self.auto_start_configuration.to_map()

        if self.auto_stop_configuration is not None:
            result['autoStopConfiguration'] = self.auto_stop_configuration.to_map()

        if self.client_token is not None:
            result['clientToken'] = self.client_token

        if self.display_release_version is not None:
            result['displayReleaseVersion'] = self.display_release_version

        if self.env_id is not None:
            result['envId'] = self.env_id

        if self.fusion is not None:
            result['fusion'] = self.fusion

        if self.kind is not None:
            result['kind'] = self.kind

        if self.name is not None:
            result['name'] = self.name

        if self.public_endpoint_enabled is not None:
            result['publicEndpointEnabled'] = self.public_endpoint_enabled

        if self.queue_name is not None:
            result['queueName'] = self.queue_name

        if self.release_version is not None:
            result['releaseVersion'] = self.release_version

        if self.region_id is not None:
            result['regionId'] = self.region_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.application_configs = []
        if m.get('applicationConfigs') is not None:
            for k1 in m.get('applicationConfigs'):
                temp_model = main_models.CreateSessionClusterRequestApplicationConfigs()
                self.application_configs.append(temp_model.from_map(k1))

        if m.get('autoStartConfiguration') is not None:
            temp_model = main_models.CreateSessionClusterRequestAutoStartConfiguration()
            self.auto_start_configuration = temp_model.from_map(m.get('autoStartConfiguration'))

        if m.get('autoStopConfiguration') is not None:
            temp_model = main_models.CreateSessionClusterRequestAutoStopConfiguration()
            self.auto_stop_configuration = temp_model.from_map(m.get('autoStopConfiguration'))

        if m.get('clientToken') is not None:
            self.client_token = m.get('clientToken')

        if m.get('displayReleaseVersion') is not None:
            self.display_release_version = m.get('displayReleaseVersion')

        if m.get('envId') is not None:
            self.env_id = m.get('envId')

        if m.get('fusion') is not None:
            self.fusion = m.get('fusion')

        if m.get('kind') is not None:
            self.kind = m.get('kind')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('publicEndpointEnabled') is not None:
            self.public_endpoint_enabled = m.get('publicEndpointEnabled')

        if m.get('queueName') is not None:
            self.queue_name = m.get('queueName')

        if m.get('releaseVersion') is not None:
            self.release_version = m.get('releaseVersion')

        if m.get('regionId') is not None:
            self.region_id = m.get('regionId')

        return self

class CreateSessionClusterRequestAutoStopConfiguration(DaraModel):
    def __init__(
        self,
        enable: bool = None,
        idle_timeout_minutes: int = None,
    ):
        # Specifies whether to enable automatic termination.
        # 
        # *   true
        # *   false
        self.enable = enable
        # The idle timeout period. The session is automatically terminated when the idle timeout period is exceeded.
        self.idle_timeout_minutes = idle_timeout_minutes

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.enable is not None:
            result['enable'] = self.enable

        if self.idle_timeout_minutes is not None:
            result['idleTimeoutMinutes'] = self.idle_timeout_minutes

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('enable') is not None:
            self.enable = m.get('enable')

        if m.get('idleTimeoutMinutes') is not None:
            self.idle_timeout_minutes = m.get('idleTimeoutMinutes')

        return self

class CreateSessionClusterRequestAutoStartConfiguration(DaraModel):
    def __init__(
        self,
        enable: bool = None,
    ):
        # Specifies whether to enable automatic startup.
        # 
        # *   true
        # *   false
        self.enable = enable

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.enable is not None:
            result['enable'] = self.enable

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('enable') is not None:
            self.enable = m.get('enable')

        return self

class CreateSessionClusterRequestApplicationConfigs(DaraModel):
    def __init__(
        self,
        config_file_name: str = None,
        config_item_key: str = None,
        config_item_value: str = None,
    ):
        # The name of the configuration file.
        self.config_file_name = config_file_name
        # The key of SparkConf.
        self.config_item_key = config_item_key
        # The value of SparkConf.
        self.config_item_value = config_item_value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.config_file_name is not None:
            result['configFileName'] = self.config_file_name

        if self.config_item_key is not None:
            result['configItemKey'] = self.config_item_key

        if self.config_item_value is not None:
            result['configItemValue'] = self.config_item_value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('configFileName') is not None:
            self.config_file_name = m.get('configFileName')

        if m.get('configItemKey') is not None:
            self.config_item_key = m.get('configItemKey')

        if m.get('configItemValue') is not None:
            self.config_item_value = m.get('configItemValue')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class ListKyuubiSparkApplicationsResponseBody(DaraModel):
    def __init__(
        self,
        applications: List[main_models.ListKyuubiSparkApplicationsResponseBodyApplications] = None,
        max_results: int = None,
        next_token: str = None,
        request_id: str = None,
        total_count: int = None,
    ):
        # The details of the applications.
        self.applications = applications
        # The maximum number of entries returned.
        self.max_results = max_results
        # A pagination token. It can be used in the next request to retrieve a new page of results.
        self.next_token = next_token
        # The request ID.
        self.request_id = request_id
        # The total number of entries returned.
        self.total_count = total_count

    def validate(self):
        if self.applications:
            for v1 in self.applications:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['applications'] = []
        if self.applications is not None:
            for k1 in self.applications:
                result['applications'].append(k1.to_map() if k1 else None)

        if self.max_results is not None:
            result['maxResults'] = self.max_results

        if self.next_token is not None:
            result['nextToken'] = self.next_token

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.total_count is not None:
            result['totalCount'] = self.total_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.applications = []
        if m.get('applications') is not None:
            for k1 in m.get('applications'):
                temp_model = main_models.ListKyuubiSparkApplicationsResponseBodyApplications()
                self.applications.append(temp_model.from_map(k1))

        if m.get('maxResults') is not None:
            self.max_results = m.get('maxResults')

        if m.get('nextToken') is not None:
            self.next_token = m.get('nextToken')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('totalCount') is not None:
            self.total_count = m.get('totalCount')

        return self

class ListKyuubiSparkApplicationsResponseBodyApplications(DaraModel):
    def __init__(
        self,
        application_id: str = None,
        application_name: str = None,
        cu_hours: float = None,
        end_time: str = None,
        exit_reason: str = None,
        kyuubi_service_id: str = None,
        latest_sql_statement_status: str = None,
        mb_seconds: int = None,
        priority: str = None,
        resource_queue_id: str = None,
        run_log: main_models.RunLog = None,
        start_time: str = None,
        state: str = None,
        tags: List[main_models.Tag] = None,
        vcore_seconds: int = None,
        web_ui: str = None,
    ):
        # The ID of the application that is submitted by using a Kyuubi gateway.
        self.application_id = application_id
        # The name of the Spark application that is submitted by using a Kyuubi gateway.
        self.application_name = application_name
        # The number of CUs consumed during a specified cycle of a task. The value is an estimated value. Refer to your Alibaba Cloud bill for the actual number of consumed CUs.
        self.cu_hours = cu_hours
        # The time when the task ended.
        self.end_time = end_time
        self.exit_reason = exit_reason
        self.kyuubi_service_id = kyuubi_service_id
        self.latest_sql_statement_status = latest_sql_statement_status
        # The total amount of memory allocated to the job multiplied by the running duration (seconds).
        self.mb_seconds = mb_seconds
        self.priority = priority
        # The name of the resource queue on which the Spark jobs run.
        self.resource_queue_id = resource_queue_id
        self.run_log = run_log
        # The time when the task started.
        self.start_time = start_time
        # The status of the Spark application.
        # 
        # *   STARTING
        # *   RUNNING
        # *   TERMINATED
        self.state = state
        self.tags = tags
        # The total number of CPU cores allocated to the job multiplied by the running duration (seconds).
        self.vcore_seconds = vcore_seconds
        # The URL of the web UI for the Spark application.
        self.web_ui = web_ui

    def validate(self):
        if self.run_log:
            self.run_log.validate()
        if self.tags:
            for v1 in self.tags:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.application_id is not None:
            result['applicationId'] = self.application_id

        if self.application_name is not None:
            result['applicationName'] = self.application_name

        if self.cu_hours is not None:
            result['cuHours'] = self.cu_hours

        if self.end_time is not None:
            result['endTime'] = self.end_time

        if self.exit_reason is not None:
            result['exitReason'] = self.exit_reason

        if self.kyuubi_service_id is not None:
            result['kyuubiServiceId'] = self.kyuubi_service_id

        if self.latest_sql_statement_status is not None:
            result['latestSqlStatementStatus'] = self.latest_sql_statement_status

        if self.mb_seconds is not None:
            result['mbSeconds'] = self.mb_seconds

        if self.priority is not None:
            result['priority'] = self.priority

        if self.resource_queue_id is not None:
            result['resourceQueueId'] = self.resource_queue_id

        if self.run_log is not None:
            result['runLog'] = self.run_log.to_map()

        if self.start_time is not None:
            result['startTime'] = self.start_time

        if self.state is not None:
            result['state'] = self.state

        result['tags'] = []
        if self.tags is not None:
            for k1 in self.tags:
                result['tags'].append(k1.to_map() if k1 else None)

        if self.vcore_seconds is not None:
            result['vcoreSeconds'] = self.vcore_seconds

        if self.web_ui is not None:
            result['webUI'] = self.web_ui

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('applicationId') is not None:
            self.application_id = m.get('applicationId')

        if m.get('applicationName') is not None:
            self.application_name = m.get('applicationName')

        if m.get('cuHours') is not None:
            self.cu_hours = m.get('cuHours')

        if m.get('endTime') is not None:
            self.end_time = m.get('endTime')

        if m.get('exitReason') is not None:
            self.exit_reason = m.get('exitReason')

        if m.get('kyuubiServiceId') is not None:
            self.kyuubi_service_id = m.get('kyuubiServiceId')

        if m.get('latestSqlStatementStatus') is not None:
            self.latest_sql_statement_status = m.get('latestSqlStatementStatus')

        if m.get('mbSeconds') is not None:
            self.mb_seconds = m.get('mbSeconds')

        if m.get('priority') is not None:
            self.priority = m.get('priority')

        if m.get('resourceQueueId') is not None:
            self.resource_queue_id = m.get('resourceQueueId')

        if m.get('runLog') is not None:
            temp_model = main_models.RunLog()
            self.run_log = temp_model.from_map(m.get('runLog'))

        if m.get('startTime') is not None:
            self.start_time = m.get('startTime')

        if m.get('state') is not None:
            self.state = m.get('state')

        self.tags = []
        if m.get('tags') is not None:
            for k1 in m.get('tags'):
                temp_model = main_models.Tag()
                self.tags.append(temp_model.from_map(k1))

        if m.get('vcoreSeconds') is not None:
            self.vcore_seconds = m.get('vcoreSeconds')

        if m.get('webUI') is not None:
            self.web_ui = m.get('webUI')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class TaskSnapshot(DaraModel):
    def __init__(
        self,
        biz_id: str = None,
        commiter: int = None,
        gmt_created: str = None,
        item: main_models.Task = None,
        message: str = None,
        task_biz_id: str = None,
        version: str = None,
    ):
        self.biz_id = biz_id
        self.commiter = commiter
        self.gmt_created = gmt_created
        self.item = item
        self.message = message
        self.task_biz_id = task_biz_id
        self.version = version

    def validate(self):
        if self.item:
            self.item.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.biz_id is not None:
            result['bizId'] = self.biz_id

        if self.commiter is not None:
            result['commiter'] = self.commiter

        if self.gmt_created is not None:
            result['gmtCreated'] = self.gmt_created

        if self.item is not None:
            result['item'] = self.item.to_map()

        if self.message is not None:
            result['message'] = self.message

        if self.task_biz_id is not None:
            result['taskBizId'] = self.task_biz_id

        if self.version is not None:
            result['version'] = self.version

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('bizId') is not None:
            self.biz_id = m.get('bizId')

        if m.get('commiter') is not None:
            self.commiter = m.get('commiter')

        if m.get('gmtCreated') is not None:
            self.gmt_created = m.get('gmtCreated')

        if m.get('item') is not None:
            temp_model = main_models.Task()
            self.item = temp_model.from_map(m.get('item'))

        if m.get('message') is not None:
            self.message = m.get('message')

        if m.get('taskBizId') is not None:
            self.task_biz_id = m.get('taskBizId')

        if m.get('version') is not None:
            self.version = m.get('version')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ListLogContentsRequest(DaraModel):
    def __init__(
        self,
        file_name: str = None,
        length: int = None,
        offset: int = None,
        region_id: str = None,
    ):
        # Full path of the file.
        self.file_name = file_name
        # Length of the log.
        self.length = length
        # Start line for query.
        self.offset = offset
        # Region ID.
        self.region_id = region_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.file_name is not None:
            result['fileName'] = self.file_name

        if self.length is not None:
            result['length'] = self.length

        if self.offset is not None:
            result['offset'] = self.offset

        if self.region_id is not None:
            result['regionId'] = self.region_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('fileName') is not None:
            self.file_name = m.get('fileName')

        if m.get('length') is not None:
            self.length = m.get('length')

        if m.get('offset') is not None:
            self.offset = m.get('offset')

        if m.get('regionId') is not None:
            self.region_id = m.get('regionId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class StartProcessInstanceRequest(DaraModel):
    def __init__(
        self,
        action: str = None,
        comments: str = None,
        email: str = None,
        interval: str = None,
        is_prod: bool = None,
        process_definition_code: int = None,
        product_namespace: str = None,
        region_id: str = None,
        runtime_queue: str = None,
        version_hash_code: str = None,
        version_number: int = None,
    ):
        self.action = action
        self.comments = comments
        self.email = email
        self.interval = interval
        # Specifies whether to run the workflow in the production environment.
        self.is_prod = is_prod
        # The workflow ID.
        # 
        # This parameter is required.
        self.process_definition_code = process_definition_code
        # The code of the service.
        # 
        # This parameter is required.
        self.product_namespace = product_namespace
        # The region ID.
        self.region_id = region_id
        # The queue on which the workflow runs.
        self.runtime_queue = runtime_queue
        # The hash code of the version.
        self.version_hash_code = version_hash_code
        # The version number of the workflow.
        self.version_number = version_number

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.action is not None:
            result['action'] = self.action

        if self.comments is not None:
            result['comments'] = self.comments

        if self.email is not None:
            result['email'] = self.email

        if self.interval is not None:
            result['interval'] = self.interval

        if self.is_prod is not None:
            result['isProd'] = self.is_prod

        if self.process_definition_code is not None:
            result['processDefinitionCode'] = self.process_definition_code

        if self.product_namespace is not None:
            result['productNamespace'] = self.product_namespace

        if self.region_id is not None:
            result['regionId'] = self.region_id

        if self.runtime_queue is not None:
            result['runtimeQueue'] = self.runtime_queue

        if self.version_hash_code is not None:
            result['versionHashCode'] = self.version_hash_code

        if self.version_number is not None:
            result['versionNumber'] = self.version_number

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('action') is not None:
            self.action = m.get('action')

        if m.get('comments') is not None:
            self.comments = m.get('comments')

        if m.get('email') is not None:
            self.email = m.get('email')

        if m.get('interval') is not None:
            self.interval = m.get('interval')

        if m.get('isProd') is not None:
            self.is_prod = m.get('isProd')

        if m.get('processDefinitionCode') is not None:
            self.process_definition_code = m.get('processDefinitionCode')

        if m.get('productNamespace') is not None:
            self.product_namespace = m.get('productNamespace')

        if m.get('regionId') is not None:
            self.region_id = m.get('regionId')

        if m.get('runtimeQueue') is not None:
            self.runtime_queue = m.get('runtimeQueue')

        if m.get('versionHashCode') is not None:
            self.version_hash_code = m.get('versionHashCode')

        if m.get('versionNumber') is not None:
            self.version_number = m.get('versionNumber')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class JobDriver(DaraModel):
    def __init__(
        self,
        spark_submit: main_models.JobDriverSparkSubmit = None,
    ):
        # The configurations of SparkSubmit.
        self.spark_submit = spark_submit

    def validate(self):
        if self.spark_submit:
            self.spark_submit.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.spark_submit is not None:
            result['sparkSubmit'] = self.spark_submit.to_map()

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('sparkSubmit') is not None:
            temp_model = main_models.JobDriverSparkSubmit()
            self.spark_submit = temp_model.from_map(m.get('sparkSubmit'))

        return self

class JobDriverSparkSubmit(DaraModel):
    def __init__(
        self,
        entry_point: str = None,
        entry_point_arguments: List[str] = None,
        spark_submit_parameters: str = None,
    ):
        # The main program of Spark.
        self.entry_point = entry_point
        # The parameters related to the main program of Spark.
        self.entry_point_arguments = entry_point_arguments
        # The command-line parameter of SparkSubmit.
        self.spark_submit_parameters = spark_submit_parameters

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.entry_point is not None:
            result['entryPoint'] = self.entry_point

        if self.entry_point_arguments is not None:
            result['entryPointArguments'] = self.entry_point_arguments

        if self.spark_submit_parameters is not None:
            result['sparkSubmitParameters'] = self.spark_submit_parameters

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('entryPoint') is not None:
            self.entry_point = m.get('entryPoint')

        if m.get('entryPointArguments') is not None:
            self.entry_point_arguments = m.get('entryPointArguments')

        if m.get('sparkSubmitParameters') is not None:
            self.spark_submit_parameters = m.get('sparkSubmitParameters')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class GetRunConfigurationResponseBody(DaraModel):
    def __init__(
        self,
        request_id: str = None,
        run_configuration: main_models.GetRunConfigurationResponseBodyRunConfiguration = None,
    ):
        # 请求ID。
        self.request_id = request_id
        self.run_configuration = run_configuration

    def validate(self):
        if self.run_configuration:
            self.run_configuration.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.run_configuration is not None:
            result['runConfiguration'] = self.run_configuration.to_map()

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('runConfiguration') is not None:
            temp_model = main_models.GetRunConfigurationResponseBodyRunConfiguration()
            self.run_configuration = temp_model.from_map(m.get('runConfiguration'))

        return self

class GetRunConfigurationResponseBodyRunConfiguration(DaraModel):
    def __init__(
        self,
        application_configs: List[main_models.GetRunConfigurationResponseBodyRunConfigurationApplicationConfigs] = None,
        log_config: main_models.GetRunConfigurationResponseBodyRunConfigurationLogConfig = None,
        runtime_configs: List[main_models.Tag] = None,
    ):
        # 应用配置项
        self.application_configs = application_configs
        self.log_config = log_config
        # 运行配置。
        self.runtime_configs = runtime_configs

    def validate(self):
        if self.application_configs:
            for v1 in self.application_configs:
                 if v1:
                    v1.validate()
        if self.log_config:
            self.log_config.validate()
        if self.runtime_configs:
            for v1 in self.runtime_configs:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['applicationConfigs'] = []
        if self.application_configs is not None:
            for k1 in self.application_configs:
                result['applicationConfigs'].append(k1.to_map() if k1 else None)

        if self.log_config is not None:
            result['logConfig'] = self.log_config.to_map()

        result['runtimeConfigs'] = []
        if self.runtime_configs is not None:
            for k1 in self.runtime_configs:
                result['runtimeConfigs'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.application_configs = []
        if m.get('applicationConfigs') is not None:
            for k1 in m.get('applicationConfigs'):
                temp_model = main_models.GetRunConfigurationResponseBodyRunConfigurationApplicationConfigs()
                self.application_configs.append(temp_model.from_map(k1))

        if m.get('logConfig') is not None:
            temp_model = main_models.GetRunConfigurationResponseBodyRunConfigurationLogConfig()
            self.log_config = temp_model.from_map(m.get('logConfig'))

        self.runtime_configs = []
        if m.get('runtimeConfigs') is not None:
            for k1 in m.get('runtimeConfigs'):
                temp_model = main_models.Tag()
                self.runtime_configs.append(temp_model.from_map(k1))

        return self

class GetRunConfigurationResponseBodyRunConfigurationLogConfig(DaraModel):
    def __init__(
        self,
        log_level: str = None,
        log_path: str = None,
    ):
        self.log_level = log_level
        self.log_path = log_path

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.log_level is not None:
            result['LogLevel'] = self.log_level

        if self.log_path is not None:
            result['LogPath'] = self.log_path

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('LogLevel') is not None:
            self.log_level = m.get('LogLevel')

        if m.get('LogPath') is not None:
            self.log_path = m.get('LogPath')

        return self

class GetRunConfigurationResponseBodyRunConfigurationApplicationConfigs(DaraModel):
    def __init__(
        self,
        config_file_name: str = None,
        config_item_key: str = None,
        config_item_value: str = None,
    ):
        # 应用配置文件名。 应用配置文件名。 ```spark-defaults.conf```
        self.config_file_name = config_file_name
        # 配置项键。 配置项键。 ```dfs.namenode.checkpoint.period```
        self.config_item_key = config_item_key
        # 配置项值。 配置项值。 ```3600s```
        self.config_item_value = config_item_value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.config_file_name is not None:
            result['configFileName'] = self.config_file_name

        if self.config_item_key is not None:
            result['configItemKey'] = self.config_item_key

        if self.config_item_value is not None:
            result['configItemValue'] = self.config_item_value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('configFileName') is not None:
            self.config_file_name = m.get('configFileName')

        if m.get('configItemKey') is not None:
            self.config_item_key = m.get('configItemKey')

        if m.get('configItemValue') is not None:
            self.config_item_value = m.get('configItemValue')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class ListLivyComputeResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.ListLivyComputeResponseBodyData = None,
        message: str = None,
        request_id: str = None,
    ):
        self.code = code
        self.data = data
        self.message = message
        self.request_id = request_id

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['code'] = self.code

        if self.data is not None:
            result['data'] = self.data.to_map()

        if self.message is not None:
            result['message'] = self.message

        if self.request_id is not None:
            result['requestId'] = self.request_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('code') is not None:
            self.code = m.get('code')

        if m.get('data') is not None:
            temp_model = main_models.ListLivyComputeResponseBodyData()
            self.data = temp_model.from_map(m.get('data'))

        if m.get('message') is not None:
            self.message = m.get('message')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        return self

class ListLivyComputeResponseBodyData(DaraModel):
    def __init__(
        self,
        livy_computes: List[main_models.ListLivyComputeResponseBodyDataLivyComputes] = None,
    ):
        self.livy_computes = livy_computes

    def validate(self):
        if self.livy_computes:
            for v1 in self.livy_computes:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['livyComputes'] = []
        if self.livy_computes is not None:
            for k1 in self.livy_computes:
                result['livyComputes'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.livy_computes = []
        if m.get('livyComputes') is not None:
            for k1 in m.get('livyComputes'):
                temp_model = main_models.ListLivyComputeResponseBodyDataLivyComputes()
                self.livy_computes.append(temp_model.from_map(k1))

        return self

class ListLivyComputeResponseBodyDataLivyComputes(DaraModel):
    def __init__(
        self,
        compute_id: str = None,
        created_by: str = None,
        endpoint: str = None,
        endpoint_inner: str = None,
        gmt_create: int = None,
        name: str = None,
        queue_name: str = None,
        start_time: int = None,
        status: str = None,
    ):
        self.compute_id = compute_id
        self.created_by = created_by
        self.endpoint = endpoint
        self.endpoint_inner = endpoint_inner
        self.gmt_create = gmt_create
        self.name = name
        self.queue_name = queue_name
        self.start_time = start_time
        self.status = status

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.compute_id is not None:
            result['computeId'] = self.compute_id

        if self.created_by is not None:
            result['createdBy'] = self.created_by

        if self.endpoint is not None:
            result['endpoint'] = self.endpoint

        if self.endpoint_inner is not None:
            result['endpointInner'] = self.endpoint_inner

        if self.gmt_create is not None:
            result['gmtCreate'] = self.gmt_create

        if self.name is not None:
            result['name'] = self.name

        if self.queue_name is not None:
            result['queueName'] = self.queue_name

        if self.start_time is not None:
            result['startTime'] = self.start_time

        if self.status is not None:
            result['status'] = self.status

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('computeId') is not None:
            self.compute_id = m.get('computeId')

        if m.get('createdBy') is not None:
            self.created_by = m.get('createdBy')

        if m.get('endpoint') is not None:
            self.endpoint = m.get('endpoint')

        if m.get('endpointInner') is not None:
            self.endpoint_inner = m.get('endpointInner')

        if m.get('gmtCreate') is not None:
            self.gmt_create = m.get('gmtCreate')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('queueName') is not None:
            self.queue_name = m.get('queueName')

        if m.get('startTime') is not None:
            self.start_time = m.get('startTime')

        if m.get('status') is not None:
            self.status = m.get('status')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import Any

from darabonba.model import DaraModel

class StartProcessInstanceResponseBody(DaraModel):
    def __init__(
        self,
        code: int = None,
        data: Any = None,
        failed: bool = None,
        http_status_code: int = None,
        msg: str = None,
        request_id: str = None,
        success: bool = None,
    ):
        # The code that is returned by the backend server.
        self.code = code
        # The data returned.
        self.data = data
        # Indicates whether the workflow fails to be run manually.
        self.failed = failed
        # The HTTP status code.
        self.http_status_code = http_status_code
        # The description of the returned code.
        self.msg = msg
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful.
        self.success = success

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['code'] = self.code

        if self.data is not None:
            result['data'] = self.data

        if self.failed is not None:
            result['failed'] = self.failed

        if self.http_status_code is not None:
            result['httpStatusCode'] = self.http_status_code

        if self.msg is not None:
            result['msg'] = self.msg

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.success is not None:
            result['success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('code') is not None:
            self.code = m.get('code')

        if m.get('data') is not None:
            self.data = m.get('data')

        if m.get('failed') is not None:
            self.failed = m.get('failed')

        if m.get('httpStatusCode') is not None:
            self.http_status_code = m.get('httpStatusCode')

        if m.get('msg') is not None:
            self.msg = m.get('msg')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('success') is not None:
            self.success = m.get('success')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from darabonba.model import DaraModel

class KerberosConf(DaraModel):
    def __init__(
        self,
        creator: str = None,
        enabled: bool = None,
        gmt_created: str = None,
        gmt_modified: str = None,
        kerberos_conf_id: str = None,
        keytabs: List[str] = None,
        krb_5conf: str = None,
        name: str = None,
        network_service_id: str = None,
        workspace_id: str = None,
    ):
        self.creator = creator
        self.enabled = enabled
        self.gmt_created = gmt_created
        self.gmt_modified = gmt_modified
        self.kerberos_conf_id = kerberos_conf_id
        self.keytabs = keytabs
        self.krb_5conf = krb_5conf
        self.name = name
        self.network_service_id = network_service_id
        self.workspace_id = workspace_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.creator is not None:
            result['creator'] = self.creator

        if self.enabled is not None:
            result['enabled'] = self.enabled

        if self.gmt_created is not None:
            result['gmtCreated'] = self.gmt_created

        if self.gmt_modified is not None:
            result['gmtModified'] = self.gmt_modified

        if self.kerberos_conf_id is not None:
            result['kerberosConfId'] = self.kerberos_conf_id

        if self.keytabs is not None:
            result['keytabs'] = self.keytabs

        if self.krb_5conf is not None:
            result['krb5Conf'] = self.krb_5conf

        if self.name is not None:
            result['name'] = self.name

        if self.network_service_id is not None:
            result['networkServiceId'] = self.network_service_id

        if self.workspace_id is not None:
            result['workspaceId'] = self.workspace_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('creator') is not None:
            self.creator = m.get('creator')

        if m.get('enabled') is not None:
            self.enabled = m.get('enabled')

        if m.get('gmtCreated') is not None:
            self.gmt_created = m.get('gmtCreated')

        if m.get('gmtModified') is not None:
            self.gmt_modified = m.get('gmtModified')

        if m.get('kerberosConfId') is not None:
            self.kerberos_conf_id = m.get('kerberosConfId')

        if m.get('keytabs') is not None:
            self.keytabs = m.get('keytabs')

        if m.get('krb5Conf') is not None:
            self.krb_5conf = m.get('krb5Conf')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('networkServiceId') is not None:
            self.network_service_id = m.get('networkServiceId')

        if m.get('workspaceId') is not None:
            self.workspace_id = m.get('workspaceId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class GetSqlStatementResponseBody(DaraModel):
    def __init__(
        self,
        data: main_models.GetSqlStatementResponseBodyData = None,
        request_id: str = None,
    ):
        # The response parameters.
        self.data = data
        # The request ID.
        self.request_id = request_id

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.data is not None:
            result['data'] = self.data.to_map()

        if self.request_id is not None:
            result['requestId'] = self.request_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('data') is not None:
            temp_model = main_models.GetSqlStatementResponseBodyData()
            self.data = temp_model.from_map(m.get('data'))

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        return self

class GetSqlStatementResponseBodyData(DaraModel):
    def __init__(
        self,
        execution_time: List[int] = None,
        sql_error_code: str = None,
        sql_error_message: str = None,
        sql_outputs: List[main_models.GetSqlStatementResponseBodyDataSqlOutputs] = None,
        state: str = None,
        statement_id: str = None,
    ):
        # The list of time that is consumed by SQL queries.
        self.execution_time = execution_time
        # The error code.
        self.sql_error_code = sql_error_code
        # The error message.
        self.sql_error_message = sql_error_message
        # The query results.
        self.sql_outputs = sql_outputs
        # The query status.
        # 
        # Valid values:
        # 
        # *   running
        # *   available
        # *   cancelled
        # *   error
        # *   cancelling
        self.state = state
        # The query ID.
        self.statement_id = statement_id

    def validate(self):
        if self.sql_outputs:
            for v1 in self.sql_outputs:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.execution_time is not None:
            result['executionTime'] = self.execution_time

        if self.sql_error_code is not None:
            result['sqlErrorCode'] = self.sql_error_code

        if self.sql_error_message is not None:
            result['sqlErrorMessage'] = self.sql_error_message

        result['sqlOutputs'] = []
        if self.sql_outputs is not None:
            for k1 in self.sql_outputs:
                result['sqlOutputs'].append(k1.to_map() if k1 else None)

        if self.state is not None:
            result['state'] = self.state

        if self.statement_id is not None:
            result['statementId'] = self.statement_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('executionTime') is not None:
            self.execution_time = m.get('executionTime')

        if m.get('sqlErrorCode') is not None:
            self.sql_error_code = m.get('sqlErrorCode')

        if m.get('sqlErrorMessage') is not None:
            self.sql_error_message = m.get('sqlErrorMessage')

        self.sql_outputs = []
        if m.get('sqlOutputs') is not None:
            for k1 in m.get('sqlOutputs'):
                temp_model = main_models.GetSqlStatementResponseBodyDataSqlOutputs()
                self.sql_outputs.append(temp_model.from_map(k1))

        if m.get('state') is not None:
            self.state = m.get('state')

        if m.get('statementId') is not None:
            self.statement_id = m.get('statementId')

        return self

class GetSqlStatementResponseBodyDataSqlOutputs(DaraModel):
    def __init__(
        self,
        rows: str = None,
        rows_file_path: str = None,
        schema: str = None,
    ):
        # The queried data, which is a string in the JSON format.
        self.rows = rows
        self.rows_file_path = rows_file_path
        # The information about the schema, which is a string in the JSON format.
        self.schema = schema

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.rows is not None:
            result['rows'] = self.rows

        if self.rows_file_path is not None:
            result['rowsFilePath'] = self.rows_file_path

        if self.schema is not None:
            result['schema'] = self.schema

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('rows') is not None:
            self.rows = m.get('rows')

        if m.get('rowsFilePath') is not None:
            self.rows_file_path = m.get('rowsFilePath')

        if m.get('schema') is not None:
            self.schema = m.get('schema')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ListKyuubiSparkApplicationsShrinkRequest(DaraModel):
    def __init__(
        self,
        application_id: str = None,
        application_name: str = None,
        end_time_shrink: str = None,
        latest_sql_statement_statuses: str = None,
        max_results: int = None,
        min_duration: int = None,
        next_token: str = None,
        order_by_shrink: str = None,
        resource_queue_id: str = None,
        sort: str = None,
        start_time_shrink: str = None,
        states: str = None,
    ):
        # The ID of the application that is submitted by using a Kyuubi gateway.
        self.application_id = application_id
        # The name of the Spark application that is submitted by using a Kyuubi gateway.
        self.application_name = application_name
        self.end_time_shrink = end_time_shrink
        self.latest_sql_statement_statuses = latest_sql_statement_statuses
        # The maximum number of entries to return.
        self.max_results = max_results
        self.min_duration = min_duration
        # The pagination token that is used in the next request to retrieve a new page of results.
        self.next_token = next_token
        self.order_by_shrink = order_by_shrink
        self.resource_queue_id = resource_queue_id
        self.sort = sort
        # The range of start time.
        self.start_time_shrink = start_time_shrink
        self.states = states

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.application_id is not None:
            result['applicationId'] = self.application_id

        if self.application_name is not None:
            result['applicationName'] = self.application_name

        if self.end_time_shrink is not None:
            result['endTime'] = self.end_time_shrink

        if self.latest_sql_statement_statuses is not None:
            result['latestSqlStatementStatuses'] = self.latest_sql_statement_statuses

        if self.max_results is not None:
            result['maxResults'] = self.max_results

        if self.min_duration is not None:
            result['minDuration'] = self.min_duration

        if self.next_token is not None:
            result['nextToken'] = self.next_token

        if self.order_by_shrink is not None:
            result['orderBy'] = self.order_by_shrink

        if self.resource_queue_id is not None:
            result['resourceQueueId'] = self.resource_queue_id

        if self.sort is not None:
            result['sort'] = self.sort

        if self.start_time_shrink is not None:
            result['startTime'] = self.start_time_shrink

        if self.states is not None:
            result['states'] = self.states

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('applicationId') is not None:
            self.application_id = m.get('applicationId')

        if m.get('applicationName') is not None:
            self.application_name = m.get('applicationName')

        if m.get('endTime') is not None:
            self.end_time_shrink = m.get('endTime')

        if m.get('latestSqlStatementStatuses') is not None:
            self.latest_sql_statement_statuses = m.get('latestSqlStatementStatuses')

        if m.get('maxResults') is not None:
            self.max_results = m.get('maxResults')

        if m.get('minDuration') is not None:
            self.min_duration = m.get('minDuration')

        if m.get('nextToken') is not None:
            self.next_token = m.get('nextToken')

        if m.get('orderBy') is not None:
            self.order_by_shrink = m.get('orderBy')

        if m.get('resourceQueueId') is not None:
            self.resource_queue_id = m.get('resourceQueueId')

        if m.get('sort') is not None:
            self.sort = m.get('sort')

        if m.get('startTime') is not None:
            self.start_time_shrink = m.get('startTime')

        if m.get('states') is not None:
            self.states = m.get('states')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class GetLivyComputeResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.GetLivyComputeResponseBodyData = None,
        message: str = None,
        request_id: str = None,
    ):
        self.code = code
        self.data = data
        self.message = message
        self.request_id = request_id

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['code'] = self.code

        if self.data is not None:
            result['data'] = self.data.to_map()

        if self.message is not None:
            result['message'] = self.message

        if self.request_id is not None:
            result['requestId'] = self.request_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('code') is not None:
            self.code = m.get('code')

        if m.get('data') is not None:
            temp_model = main_models.GetLivyComputeResponseBodyData()
            self.data = temp_model.from_map(m.get('data'))

        if m.get('message') is not None:
            self.message = m.get('message')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        return self

class GetLivyComputeResponseBodyData(DaraModel):
    def __init__(
        self,
        auth_type: str = None,
        auto_stop_configuration: main_models.GetLivyComputeResponseBodyDataAutoStopConfiguration = None,
        compute_id: str = None,
        cpu_limit: str = None,
        created_by: str = None,
        display_release_version: str = None,
        enable_public: bool = None,
        endpoint: str = None,
        endpoint_inner: str = None,
        environment_id: str = None,
        fusion: bool = None,
        gmt_create: int = None,
        livy_server_conf: str = None,
        livy_version: str = None,
        memory_limit: str = None,
        name: str = None,
        network_name: str = None,
        queue_name: str = None,
        ram_user_id: str = None,
        release_version: str = None,
        start_time: int = None,
        status: str = None,
    ):
        self.auth_type = auth_type
        self.auto_stop_configuration = auto_stop_configuration
        self.compute_id = compute_id
        self.cpu_limit = cpu_limit
        self.created_by = created_by
        self.display_release_version = display_release_version
        self.enable_public = enable_public
        self.endpoint = endpoint
        self.endpoint_inner = endpoint_inner
        self.environment_id = environment_id
        self.fusion = fusion
        self.gmt_create = gmt_create
        self.livy_server_conf = livy_server_conf
        self.livy_version = livy_version
        self.memory_limit = memory_limit
        self.name = name
        self.network_name = network_name
        self.queue_name = queue_name
        self.ram_user_id = ram_user_id
        self.release_version = release_version
        self.start_time = start_time
        self.status = status

    def validate(self):
        if self.auto_stop_configuration:
            self.auto_stop_configuration.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.auth_type is not None:
            result['authType'] = self.auth_type

        if self.auto_stop_configuration is not None:
            result['autoStopConfiguration'] = self.auto_stop_configuration.to_map()

        if self.compute_id is not None:
            result['computeId'] = self.compute_id

        if self.cpu_limit is not None:
            result['cpuLimit'] = self.cpu_limit

        if self.created_by is not None:
            result['createdBy'] = self.created_by

        if self.display_release_version is not None:
            result['displayReleaseVersion'] = self.display_release_version

        if self.enable_public is not None:
            result['enablePublic'] = self.enable_public

        if self.endpoint is not None:
            result['endpoint'] = self.endpoint

        if self.endpoint_inner is not None:
            result['endpointInner'] = self.endpoint_inner

        if self.environment_id is not None:
            result['environmentId'] = self.environment_id

        if self.fusion is not None:
            result['fusion'] = self.fusion

        if self.gmt_create is not None:
            result['gmtCreate'] = self.gmt_create

        if self.livy_server_conf is not None:
            result['livyServerConf'] = self.livy_server_conf

        if self.livy_version is not None:
            result['livyVersion'] = self.livy_version

        if self.memory_limit is not None:
            result['memoryLimit'] = self.memory_limit

        if self.name is not None:
            result['name'] = self.name

        if self.network_name is not None:
            result['networkName'] = self.network_name

        if self.queue_name is not None:
            result['queueName'] = self.queue_name

        if self.ram_user_id is not None:
            result['ramUserId'] = self.ram_user_id

        if self.release_version is not None:
            result['releaseVersion'] = self.release_version

        if self.start_time is not None:
            result['startTime'] = self.start_time

        if self.status is not None:
            result['status'] = self.status

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('authType') is not None:
            self.auth_type = m.get('authType')

        if m.get('autoStopConfiguration') is not None:
            temp_model = main_models.GetLivyComputeResponseBodyDataAutoStopConfiguration()
            self.auto_stop_configuration = temp_model.from_map(m.get('autoStopConfiguration'))

        if m.get('computeId') is not None:
            self.compute_id = m.get('computeId')

        if m.get('cpuLimit') is not None:
            self.cpu_limit = m.get('cpuLimit')

        if m.get('createdBy') is not None:
            self.created_by = m.get('createdBy')

        if m.get('displayReleaseVersion') is not None:
            self.display_release_version = m.get('displayReleaseVersion')

        if m.get('enablePublic') is not None:
            self.enable_public = m.get('enablePublic')

        if m.get('endpoint') is not None:
            self.endpoint = m.get('endpoint')

        if m.get('endpointInner') is not None:
            self.endpoint_inner = m.get('endpointInner')

        if m.get('environmentId') is not None:
            self.environment_id = m.get('environmentId')

        if m.get('fusion') is not None:
            self.fusion = m.get('fusion')

        if m.get('gmtCreate') is not None:
            self.gmt_create = m.get('gmtCreate')

        if m.get('livyServerConf') is not None:
            self.livy_server_conf = m.get('livyServerConf')

        if m.get('livyVersion') is not None:
            self.livy_version = m.get('livyVersion')

        if m.get('memoryLimit') is not None:
            self.memory_limit = m.get('memoryLimit')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('networkName') is not None:
            self.network_name = m.get('networkName')

        if m.get('queueName') is not None:
            self.queue_name = m.get('queueName')

        if m.get('ramUserId') is not None:
            self.ram_user_id = m.get('ramUserId')

        if m.get('releaseVersion') is not None:
            self.release_version = m.get('releaseVersion')

        if m.get('startTime') is not None:
            self.start_time = m.get('startTime')

        if m.get('status') is not None:
            self.status = m.get('status')

        return self

class GetLivyComputeResponseBodyDataAutoStopConfiguration(DaraModel):
    def __init__(
        self,
        enable: bool = None,
        idle_timeout_minutes: int = None,
    ):
        self.enable = enable
        self.idle_timeout_minutes = idle_timeout_minutes

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.enable is not None:
            result['enable'] = self.enable

        if self.idle_timeout_minutes is not None:
            result['idleTimeoutMinutes'] = self.idle_timeout_minutes

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('enable') is not None:
            self.enable = m.get('enable')

        if m.get('idleTimeoutMinutes') is not None:
            self.idle_timeout_minutes = m.get('idleTimeoutMinutes')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class UpdateProcessDefinitionWithScheduleShrinkRequest(DaraModel):
    def __init__(
        self,
        alert_email_address: str = None,
        description: str = None,
        execution_type: str = None,
        global_params_shrink: str = None,
        name: str = None,
        product_namespace: str = None,
        publish: bool = None,
        region_id: str = None,
        release_state: str = None,
        resource_queue: str = None,
        retry_times: int = None,
        run_as: str = None,
        schedule_shrink: str = None,
        tags_shrink: str = None,
        task_definition_json_shrink: str = None,
        task_parallelism: int = None,
        task_relation_json_shrink: str = None,
        timeout: int = None,
    ):
        # The email address to receive alerts.
        self.alert_email_address = alert_email_address
        # The description of the workflow.
        self.description = description
        # The execution policy.
        # 
        # This parameter is required.
        self.execution_type = execution_type
        self.global_params_shrink = global_params_shrink
        # The name of the workflow.
        # 
        # This parameter is required.
        self.name = name
        # The code of the service.
        # 
        # This parameter is required.
        self.product_namespace = product_namespace
        # Specifies whether to publish the workflow.
        self.publish = publish
        # The region ID.
        self.region_id = region_id
        # The status of the workflow.
        self.release_state = release_state
        # The resource queue.
        self.resource_queue = resource_queue
        # The number of retries.
        self.retry_times = retry_times
        # The execution user.
        self.run_as = run_as
        # The scheduling settings.
        self.schedule_shrink = schedule_shrink
        # The tags.
        self.tags_shrink = tags_shrink
        # The descriptions of all nodes in the workflow.
        # 
        # This parameter is required.
        self.task_definition_json_shrink = task_definition_json_shrink
        # The node parallelism.
        self.task_parallelism = task_parallelism
        # The dependencies of all nodes in the workflow. preTaskCode specifies the ID of an upstream node, and postTaskCode specifies the ID of a downstream node. The ID of each node is unique. If a node does not have an upstream node, set preTaskCode to 0.
        # 
        # This parameter is required.
        self.task_relation_json_shrink = task_relation_json_shrink
        # The default timeout period of the workflow.
        self.timeout = timeout

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.alert_email_address is not None:
            result['alertEmailAddress'] = self.alert_email_address

        if self.description is not None:
            result['description'] = self.description

        if self.execution_type is not None:
            result['executionType'] = self.execution_type

        if self.global_params_shrink is not None:
            result['globalParams'] = self.global_params_shrink

        if self.name is not None:
            result['name'] = self.name

        if self.product_namespace is not None:
            result['productNamespace'] = self.product_namespace

        if self.publish is not None:
            result['publish'] = self.publish

        if self.region_id is not None:
            result['regionId'] = self.region_id

        if self.release_state is not None:
            result['releaseState'] = self.release_state

        if self.resource_queue is not None:
            result['resourceQueue'] = self.resource_queue

        if self.retry_times is not None:
            result['retryTimes'] = self.retry_times

        if self.run_as is not None:
            result['runAs'] = self.run_as

        if self.schedule_shrink is not None:
            result['schedule'] = self.schedule_shrink

        if self.tags_shrink is not None:
            result['tags'] = self.tags_shrink

        if self.task_definition_json_shrink is not None:
            result['taskDefinitionJson'] = self.task_definition_json_shrink

        if self.task_parallelism is not None:
            result['taskParallelism'] = self.task_parallelism

        if self.task_relation_json_shrink is not None:
            result['taskRelationJson'] = self.task_relation_json_shrink

        if self.timeout is not None:
            result['timeout'] = self.timeout

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('alertEmailAddress') is not None:
            self.alert_email_address = m.get('alertEmailAddress')

        if m.get('description') is not None:
            self.description = m.get('description')

        if m.get('executionType') is not None:
            self.execution_type = m.get('executionType')

        if m.get('globalParams') is not None:
            self.global_params_shrink = m.get('globalParams')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('productNamespace') is not None:
            self.product_namespace = m.get('productNamespace')

        if m.get('publish') is not None:
            self.publish = m.get('publish')

        if m.get('regionId') is not None:
            self.region_id = m.get('regionId')

        if m.get('releaseState') is not None:
            self.release_state = m.get('releaseState')

        if m.get('resourceQueue') is not None:
            self.resource_queue = m.get('resourceQueue')

        if m.get('retryTimes') is not None:
            self.retry_times = m.get('retryTimes')

        if m.get('runAs') is not None:
            self.run_as = m.get('runAs')

        if m.get('schedule') is not None:
            self.schedule_shrink = m.get('schedule')

        if m.get('tags') is not None:
            self.tags_shrink = m.get('tags')

        if m.get('taskDefinitionJson') is not None:
            self.task_definition_json_shrink = m.get('taskDefinitionJson')

        if m.get('taskParallelism') is not None:
            self.task_parallelism = m.get('taskParallelism')

        if m.get('taskRelationJson') is not None:
            self.task_relation_json_shrink = m.get('taskRelationJson')

        if m.get('timeout') is not None:
            self.timeout = m.get('timeout')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class Template(DaraModel):
    def __init__(
        self,
        biz_id: str = None,
        creator: int = None,
        display_spark_version: str = None,
        fusion: bool = None,
        gmt_created: str = None,
        gmt_modified: str = None,
        is_default: bool = None,
        modifier: int = None,
        name: str = None,
        spark_conf: List[main_models.SparkConf] = None,
        spark_driver_cores: int = None,
        spark_driver_memory: int = None,
        spark_executor_cores: int = None,
        spark_executor_memory: int = None,
        spark_log_level: str = None,
        spark_log_path: str = None,
        spark_version: str = None,
        template_type: str = None,
    ):
        self.biz_id = biz_id
        # The user ID of the job creator.
        # 
        # This parameter is required.
        self.creator = creator
        # The displayed version of the Spark engine.
        self.display_spark_version = display_spark_version
        # Indicates whether Fusion engine is enabled for acceleration.
        self.fusion = fusion
        # The creation time.
        # 
        # This parameter is required.
        self.gmt_created = gmt_created
        # The time when the job was last modified.
        # 
        # This parameter is required.
        self.gmt_modified = gmt_modified
        self.is_default = is_default
        # The ID of the user who last modified the job.
        # 
        # This parameter is required.
        self.modifier = modifier
        self.name = name
        # The SparkConf objects.
        self.spark_conf = spark_conf
        # The number of driver cores of the Spark job.
        # 
        # This parameter is required.
        self.spark_driver_cores = spark_driver_cores
        # The size of driver memory of the Spark job.
        # 
        # This parameter is required.
        self.spark_driver_memory = spark_driver_memory
        # The number of executor cores of the Spark job.
        # 
        # This parameter is required.
        self.spark_executor_cores = spark_executor_cores
        # The size of executor memory of the Spark job.
        # 
        # This parameter is required.
        self.spark_executor_memory = spark_executor_memory
        # The level of the Spark log.
        # 
        # This parameter is required.
        self.spark_log_level = spark_log_level
        # The path where the operational logs of the Spark job are stored.
        # 
        # This parameter is required.
        self.spark_log_path = spark_log_path
        # The engine version of Spark.
        # 
        # This parameter is required.
        self.spark_version = spark_version
        # The template type.
        self.template_type = template_type

    def validate(self):
        if self.spark_conf:
            for v1 in self.spark_conf:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.biz_id is not None:
            result['bizId'] = self.biz_id

        if self.creator is not None:
            result['creator'] = self.creator

        if self.display_spark_version is not None:
            result['displaySparkVersion'] = self.display_spark_version

        if self.fusion is not None:
            result['fusion'] = self.fusion

        if self.gmt_created is not None:
            result['gmtCreated'] = self.gmt_created

        if self.gmt_modified is not None:
            result['gmtModified'] = self.gmt_modified

        if self.is_default is not None:
            result['isDefault'] = self.is_default

        if self.modifier is not None:
            result['modifier'] = self.modifier

        if self.name is not None:
            result['name'] = self.name

        result['sparkConf'] = []
        if self.spark_conf is not None:
            for k1 in self.spark_conf:
                result['sparkConf'].append(k1.to_map() if k1 else None)

        if self.spark_driver_cores is not None:
            result['sparkDriverCores'] = self.spark_driver_cores

        if self.spark_driver_memory is not None:
            result['sparkDriverMemory'] = self.spark_driver_memory

        if self.spark_executor_cores is not None:
            result['sparkExecutorCores'] = self.spark_executor_cores

        if self.spark_executor_memory is not None:
            result['sparkExecutorMemory'] = self.spark_executor_memory

        if self.spark_log_level is not None:
            result['sparkLogLevel'] = self.spark_log_level

        if self.spark_log_path is not None:
            result['sparkLogPath'] = self.spark_log_path

        if self.spark_version is not None:
            result['sparkVersion'] = self.spark_version

        if self.template_type is not None:
            result['templateType'] = self.template_type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('bizId') is not None:
            self.biz_id = m.get('bizId')

        if m.get('creator') is not None:
            self.creator = m.get('creator')

        if m.get('displaySparkVersion') is not None:
            self.display_spark_version = m.get('displaySparkVersion')

        if m.get('fusion') is not None:
            self.fusion = m.get('fusion')

        if m.get('gmtCreated') is not None:
            self.gmt_created = m.get('gmtCreated')

        if m.get('gmtModified') is not None:
            self.gmt_modified = m.get('gmtModified')

        if m.get('isDefault') is not None:
            self.is_default = m.get('isDefault')

        if m.get('modifier') is not None:
            self.modifier = m.get('modifier')

        if m.get('name') is not None:
            self.name = m.get('name')

        self.spark_conf = []
        if m.get('sparkConf') is not None:
            for k1 in m.get('sparkConf'):
                temp_model = main_models.SparkConf()
                self.spark_conf.append(temp_model.from_map(k1))

        if m.get('sparkDriverCores') is not None:
            self.spark_driver_cores = m.get('sparkDriverCores')

        if m.get('sparkDriverMemory') is not None:
            self.spark_driver_memory = m.get('sparkDriverMemory')

        if m.get('sparkExecutorCores') is not None:
            self.spark_executor_cores = m.get('sparkExecutorCores')

        if m.get('sparkExecutorMemory') is not None:
            self.spark_executor_memory = m.get('sparkExecutorMemory')

        if m.get('sparkLogLevel') is not None:
            self.spark_log_level = m.get('sparkLogLevel')

        if m.get('sparkLogPath') is not None:
            self.spark_log_path = m.get('sparkLogPath')

        if m.get('sparkVersion') is not None:
            self.spark_version = m.get('sparkVersion')

        if m.get('templateType') is not None:
            self.template_type = m.get('templateType')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetCuHoursRequest(DaraModel):
    def __init__(
        self,
        end_time: str = None,
        start_time: str = None,
    ):
        # The end time of the query time range.
        # 
        # This parameter is required.
        self.end_time = end_time
        # The start time of the query time range.
        # 
        # This parameter is required.
        self.start_time = start_time

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.end_time is not None:
            result['endTime'] = self.end_time

        if self.start_time is not None:
            result['startTime'] = self.start_time

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('endTime') is not None:
            self.end_time = m.get('endTime')

        if m.get('startTime') is not None:
            self.start_time = m.get('startTime')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class EditWorkspaceQueueRequest(DaraModel):
    def __init__(
        self,
        environments: List[str] = None,
        gpu_spec: List[str] = None,
        resource_spec: main_models.EditWorkspaceQueueRequestResourceSpec = None,
        workspace_id: str = None,
        workspace_queue_name: str = None,
        region_id: str = None,
    ):
        self.environments = environments
        self.gpu_spec = gpu_spec
        self.resource_spec = resource_spec
        self.workspace_id = workspace_id
        self.workspace_queue_name = workspace_queue_name
        self.region_id = region_id

    def validate(self):
        if self.resource_spec:
            self.resource_spec.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.environments is not None:
            result['environments'] = self.environments

        if self.gpu_spec is not None:
            result['gpuSpec'] = self.gpu_spec

        if self.resource_spec is not None:
            result['resourceSpec'] = self.resource_spec.to_map()

        if self.workspace_id is not None:
            result['workspaceId'] = self.workspace_id

        if self.workspace_queue_name is not None:
            result['workspaceQueueName'] = self.workspace_queue_name

        if self.region_id is not None:
            result['regionId'] = self.region_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('environments') is not None:
            self.environments = m.get('environments')

        if m.get('gpuSpec') is not None:
            self.gpu_spec = m.get('gpuSpec')

        if m.get('resourceSpec') is not None:
            temp_model = main_models.EditWorkspaceQueueRequestResourceSpec()
            self.resource_spec = temp_model.from_map(m.get('resourceSpec'))

        if m.get('workspaceId') is not None:
            self.workspace_id = m.get('workspaceId')

        if m.get('workspaceQueueName') is not None:
            self.workspace_queue_name = m.get('workspaceQueueName')

        if m.get('regionId') is not None:
            self.region_id = m.get('regionId')

        return self

class EditWorkspaceQueueRequestResourceSpec(DaraModel):
    def __init__(
        self,
        cu: int = None,
        gpu: int = None,
        max_cu: int = None,
    ):
        self.cu = cu
        self.gpu = gpu
        self.max_cu = max_cu

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cu is not None:
            result['cu'] = self.cu

        if self.gpu is not None:
            result['gpu'] = self.gpu

        if self.max_cu is not None:
            result['maxCu'] = self.max_cu

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('cu') is not None:
            self.cu = m.get('cu')

        if m.get('gpu') is not None:
            self.gpu = m.get('gpu')

        if m.get('maxCu') is not None:
            self.max_cu = m.get('maxCu')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class ListJobRunsResponseBody(DaraModel):
    def __init__(
        self,
        job_runs: List[main_models.ListJobRunsResponseBodyJobRuns] = None,
        max_results: int = None,
        next_token: str = None,
        request_id: str = None,
        total_count: int = None,
    ):
        # The Spark jobs.
        self.job_runs = job_runs
        # The maximum number of entries returned.
        self.max_results = max_results
        # A pagination token.
        self.next_token = next_token
        # The request ID.
        self.request_id = request_id
        # The total number of entries returned.
        self.total_count = total_count

    def validate(self):
        if self.job_runs:
            for v1 in self.job_runs:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['jobRuns'] = []
        if self.job_runs is not None:
            for k1 in self.job_runs:
                result['jobRuns'].append(k1.to_map() if k1 else None)

        if self.max_results is not None:
            result['maxResults'] = self.max_results

        if self.next_token is not None:
            result['nextToken'] = self.next_token

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.total_count is not None:
            result['totalCount'] = self.total_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.job_runs = []
        if m.get('jobRuns') is not None:
            for k1 in m.get('jobRuns'):
                temp_model = main_models.ListJobRunsResponseBodyJobRuns()
                self.job_runs.append(temp_model.from_map(k1))

        if m.get('maxResults') is not None:
            self.max_results = m.get('maxResults')

        if m.get('nextToken') is not None:
            self.next_token = m.get('nextToken')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('totalCount') is not None:
            self.total_count = m.get('totalCount')

        return self

class ListJobRunsResponseBodyJobRuns(DaraModel):
    def __init__(
        self,
        code_type: str = None,
        configuration_overrides: main_models.ListJobRunsResponseBodyJobRunsConfigurationOverrides = None,
        creator: str = None,
        cu_hours: float = None,
        display_release_version: str = None,
        end_time: int = None,
        execution_timeout_seconds: int = None,
        fusion: bool = None,
        job_driver: main_models.JobDriver = None,
        job_run_id: str = None,
        log: main_models.RunLog = None,
        mb_seconds: int = None,
        name: str = None,
        priority: str = None,
        release_version: str = None,
        resource_queue_id: str = None,
        state: str = None,
        state_change_reason: main_models.ListJobRunsResponseBodyJobRunsStateChangeReason = None,
        submit_time: int = None,
        tags: List[main_models.Tag] = None,
        vcore_seconds: int = None,
        web_ui: str = None,
        workspace_id: str = None,
    ):
        # The code type of the job. Valid values:
        # 
        # SQL
        # 
        # JAR
        # 
        # PYTHON
        self.code_type = code_type
        # The advanced configurations of Spark.
        self.configuration_overrides = configuration_overrides
        # The ID of the user who created the job.
        self.creator = creator
        # The number of CUs consumed during a specified cycle of a task. The value is an estimated value. Refer to your Alibaba Cloud bill for the actual number of consumed CUs.
        self.cu_hours = cu_hours
        # The version of Spark on which the jobs run.
        self.display_release_version = display_release_version
        # The end time of the job.
        self.end_time = end_time
        # The timeout period of the job.
        self.execution_timeout_seconds = execution_timeout_seconds
        # Indicates whether the Fusion engine is used for acceleration.
        self.fusion = fusion
        # The information about Spark Driver.
        self.job_driver = job_driver
        # The job ID.
        self.job_run_id = job_run_id
        # The path where the operational logs are stored.
        self.log = log
        # The total amount of memory allocated to the job multiplied by the running duration (seconds).
        self.mb_seconds = mb_seconds
        # The job name.
        self.name = name
        self.priority = priority
        # The version of Spark on which the jobs run.
        self.release_version = release_version
        self.resource_queue_id = resource_queue_id
        # The job state.
        self.state = state
        # The reason of the job status change.
        self.state_change_reason = state_change_reason
        # The time when the job was submitted.
        self.submit_time = submit_time
        # The tags of the job.
        self.tags = tags
        # The total number of CPU cores allocated to the job multiplied by the running duration (seconds).
        self.vcore_seconds = vcore_seconds
        # The web UI of the job.
        self.web_ui = web_ui
        # The workspace ID.
        self.workspace_id = workspace_id

    def validate(self):
        if self.configuration_overrides:
            self.configuration_overrides.validate()
        if self.job_driver:
            self.job_driver.validate()
        if self.log:
            self.log.validate()
        if self.state_change_reason:
            self.state_change_reason.validate()
        if self.tags:
            for v1 in self.tags:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code_type is not None:
            result['codeType'] = self.code_type

        if self.configuration_overrides is not None:
            result['configurationOverrides'] = self.configuration_overrides.to_map()

        if self.creator is not None:
            result['creator'] = self.creator

        if self.cu_hours is not None:
            result['cuHours'] = self.cu_hours

        if self.display_release_version is not None:
            result['displayReleaseVersion'] = self.display_release_version

        if self.end_time is not None:
            result['endTime'] = self.end_time

        if self.execution_timeout_seconds is not None:
            result['executionTimeoutSeconds'] = self.execution_timeout_seconds

        if self.fusion is not None:
            result['fusion'] = self.fusion

        if self.job_driver is not None:
            result['jobDriver'] = self.job_driver.to_map()

        if self.job_run_id is not None:
            result['jobRunId'] = self.job_run_id

        if self.log is not None:
            result['log'] = self.log.to_map()

        if self.mb_seconds is not None:
            result['mbSeconds'] = self.mb_seconds

        if self.name is not None:
            result['name'] = self.name

        if self.priority is not None:
            result['priority'] = self.priority

        if self.release_version is not None:
            result['releaseVersion'] = self.release_version

        if self.resource_queue_id is not None:
            result['resourceQueueId'] = self.resource_queue_id

        if self.state is not None:
            result['state'] = self.state

        if self.state_change_reason is not None:
            result['stateChangeReason'] = self.state_change_reason.to_map()

        if self.submit_time is not None:
            result['submitTime'] = self.submit_time

        result['tags'] = []
        if self.tags is not None:
            for k1 in self.tags:
                result['tags'].append(k1.to_map() if k1 else None)

        if self.vcore_seconds is not None:
            result['vcoreSeconds'] = self.vcore_seconds

        if self.web_ui is not None:
            result['webUI'] = self.web_ui

        if self.workspace_id is not None:
            result['workspaceId'] = self.workspace_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('codeType') is not None:
            self.code_type = m.get('codeType')

        if m.get('configurationOverrides') is not None:
            temp_model = main_models.ListJobRunsResponseBodyJobRunsConfigurationOverrides()
            self.configuration_overrides = temp_model.from_map(m.get('configurationOverrides'))

        if m.get('creator') is not None:
            self.creator = m.get('creator')

        if m.get('cuHours') is not None:
            self.cu_hours = m.get('cuHours')

        if m.get('displayReleaseVersion') is not None:
            self.display_release_version = m.get('displayReleaseVersion')

        if m.get('endTime') is not None:
            self.end_time = m.get('endTime')

        if m.get('executionTimeoutSeconds') is not None:
            self.execution_timeout_seconds = m.get('executionTimeoutSeconds')

        if m.get('fusion') is not None:
            self.fusion = m.get('fusion')

        if m.get('jobDriver') is not None:
            temp_model = main_models.JobDriver()
            self.job_driver = temp_model.from_map(m.get('jobDriver'))

        if m.get('jobRunId') is not None:
            self.job_run_id = m.get('jobRunId')

        if m.get('log') is not None:
            temp_model = main_models.RunLog()
            self.log = temp_model.from_map(m.get('log'))

        if m.get('mbSeconds') is not None:
            self.mb_seconds = m.get('mbSeconds')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('priority') is not None:
            self.priority = m.get('priority')

        if m.get('releaseVersion') is not None:
            self.release_version = m.get('releaseVersion')

        if m.get('resourceQueueId') is not None:
            self.resource_queue_id = m.get('resourceQueueId')

        if m.get('state') is not None:
            self.state = m.get('state')

        if m.get('stateChangeReason') is not None:
            temp_model = main_models.ListJobRunsResponseBodyJobRunsStateChangeReason()
            self.state_change_reason = temp_model.from_map(m.get('stateChangeReason'))

        if m.get('submitTime') is not None:
            self.submit_time = m.get('submitTime')

        self.tags = []
        if m.get('tags') is not None:
            for k1 in m.get('tags'):
                temp_model = main_models.Tag()
                self.tags.append(temp_model.from_map(k1))

        if m.get('vcoreSeconds') is not None:
            self.vcore_seconds = m.get('vcoreSeconds')

        if m.get('webUI') is not None:
            self.web_ui = m.get('webUI')

        if m.get('workspaceId') is not None:
            self.workspace_id = m.get('workspaceId')

        return self

class ListJobRunsResponseBodyJobRunsStateChangeReason(DaraModel):
    def __init__(
        self,
        code: str = None,
        message: str = None,
    ):
        # The error code.
        self.code = code
        # The error message.
        self.message = message

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['code'] = self.code

        if self.message is not None:
            result['message'] = self.message

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('code') is not None:
            self.code = m.get('code')

        if m.get('message') is not None:
            self.message = m.get('message')

        return self

class ListJobRunsResponseBodyJobRunsConfigurationOverrides(DaraModel):
    def __init__(
        self,
        configurations: List[main_models.Configuration] = None,
    ):
        # The SparkConf objects.
        self.configurations = configurations

    def validate(self):
        if self.configurations:
            for v1 in self.configurations:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['configurations'] = []
        if self.configurations is not None:
            for k1 in self.configurations:
                result['configurations'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.configurations = []
        if m.get('configurations') is not None:
            for k1 in m.get('configurations'):
                temp_model = main_models.Configuration()
                self.configurations.append(temp_model.from_map(k1))

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetTemplateRequest(DaraModel):
    def __init__(
        self,
        region_id: str = None,
        template_biz_id: str = None,
        template_type: str = None,
    ):
        # The region ID.
        self.region_id = region_id
        self.template_biz_id = template_biz_id
        # The template type.
        # 
        # Valid values:
        # 
        # *   TASK
        # *   SESSION
        self.template_type = template_type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.region_id is not None:
            result['regionId'] = self.region_id

        if self.template_biz_id is not None:
            result['templateBizId'] = self.template_biz_id

        if self.template_type is not None:
            result['templateType'] = self.template_type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('regionId') is not None:
            self.region_id = m.get('regionId')

        if m.get('templateBizId') is not None:
            self.template_biz_id = m.get('templateBizId')

        if m.get('templateType') is not None:
            self.template_type = m.get('templateType')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class Configuration(DaraModel):
    def __init__(
        self,
        config_file_name: str = None,
        config_item_key: str = None,
        config_item_value: str = None,
    ):
        # The name of the configuration file.
        self.config_file_name = config_file_name
        # The name of the configuration item.
        self.config_item_key = config_item_key
        # The value of the configuration item.
        self.config_item_value = config_item_value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.config_file_name is not None:
            result['configFileName'] = self.config_file_name

        if self.config_item_key is not None:
            result['configItemKey'] = self.config_item_key

        if self.config_item_value is not None:
            result['configItemValue'] = self.config_item_value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('configFileName') is not None:
            self.config_file_name = m.get('configFileName')

        if m.get('configItemKey') is not None:
            self.config_item_key = m.get('configItemKey')

        if m.get('configItemValue') is not None:
            self.config_item_value = m.get('configItemValue')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class UpdateRayClusterRequest(DaraModel):
    def __init__(
        self,
        description: str = None,
        display_release_version: str = None,
        extra_param: str = None,
        head_spec: main_models.UpdateRayClusterRequestHeadSpec = None,
        name: str = None,
        network_service_name: str = None,
        volume_ids: List[str] = None,
        worker_spec: List[main_models.UpdateRayClusterRequestWorkerSpec] = None,
    ):
        self.description = description
        self.display_release_version = display_release_version
        self.extra_param = extra_param
        self.head_spec = head_spec
        self.name = name
        self.network_service_name = network_service_name
        self.volume_ids = volume_ids
        self.worker_spec = worker_spec

    def validate(self):
        if self.head_spec:
            self.head_spec.validate()
        if self.worker_spec:
            for v1 in self.worker_spec:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.description is not None:
            result['description'] = self.description

        if self.display_release_version is not None:
            result['displayReleaseVersion'] = self.display_release_version

        if self.extra_param is not None:
            result['extraParam'] = self.extra_param

        if self.head_spec is not None:
            result['headSpec'] = self.head_spec.to_map()

        if self.name is not None:
            result['name'] = self.name

        if self.network_service_name is not None:
            result['networkServiceName'] = self.network_service_name

        if self.volume_ids is not None:
            result['volumeIds'] = self.volume_ids

        result['workerSpec'] = []
        if self.worker_spec is not None:
            for k1 in self.worker_spec:
                result['workerSpec'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('description') is not None:
            self.description = m.get('description')

        if m.get('displayReleaseVersion') is not None:
            self.display_release_version = m.get('displayReleaseVersion')

        if m.get('extraParam') is not None:
            self.extra_param = m.get('extraParam')

        if m.get('headSpec') is not None:
            temp_model = main_models.UpdateRayClusterRequestHeadSpec()
            self.head_spec = temp_model.from_map(m.get('headSpec'))

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('networkServiceName') is not None:
            self.network_service_name = m.get('networkServiceName')

        if m.get('volumeIds') is not None:
            self.volume_ids = m.get('volumeIds')

        self.worker_spec = []
        if m.get('workerSpec') is not None:
            for k1 in m.get('workerSpec'):
                temp_model = main_models.UpdateRayClusterRequestWorkerSpec()
                self.worker_spec.append(temp_model.from_map(k1))

        return self

class UpdateRayClusterRequestWorkerSpec(DaraModel):
    def __init__(
        self,
        cpu: str = None,
        gpu_spec: str = None,
        group_name: str = None,
        max_replica: int = None,
        memory: str = None,
        min_replica: int = None,
        queue_name: str = None,
        replica: int = None,
        worker_type: str = None,
    ):
        self.cpu = cpu
        self.gpu_spec = gpu_spec
        self.group_name = group_name
        self.max_replica = max_replica
        self.memory = memory
        self.min_replica = min_replica
        self.queue_name = queue_name
        self.replica = replica
        self.worker_type = worker_type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cpu is not None:
            result['cpu'] = self.cpu

        if self.gpu_spec is not None:
            result['gpuSpec'] = self.gpu_spec

        if self.group_name is not None:
            result['groupName'] = self.group_name

        if self.max_replica is not None:
            result['maxReplica'] = self.max_replica

        if self.memory is not None:
            result['memory'] = self.memory

        if self.min_replica is not None:
            result['minReplica'] = self.min_replica

        if self.queue_name is not None:
            result['queueName'] = self.queue_name

        if self.replica is not None:
            result['replica'] = self.replica

        if self.worker_type is not None:
            result['workerType'] = self.worker_type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('cpu') is not None:
            self.cpu = m.get('cpu')

        if m.get('gpuSpec') is not None:
            self.gpu_spec = m.get('gpuSpec')

        if m.get('groupName') is not None:
            self.group_name = m.get('groupName')

        if m.get('maxReplica') is not None:
            self.max_replica = m.get('maxReplica')

        if m.get('memory') is not None:
            self.memory = m.get('memory')

        if m.get('minReplica') is not None:
            self.min_replica = m.get('minReplica')

        if m.get('queueName') is not None:
            self.queue_name = m.get('queueName')

        if m.get('replica') is not None:
            self.replica = m.get('replica')

        if m.get('workerType') is not None:
            self.worker_type = m.get('workerType')

        return self

class UpdateRayClusterRequestHeadSpec(DaraModel):
    def __init__(
        self,
        cpu: str = None,
        enable_auto_scaling: bool = None,
        gpu_spec: str = None,
        idle_timeout_seconds: int = None,
        memory: str = None,
        queue_name: str = None,
    ):
        self.cpu = cpu
        self.enable_auto_scaling = enable_auto_scaling
        self.gpu_spec = gpu_spec
        self.idle_timeout_seconds = idle_timeout_seconds
        self.memory = memory
        self.queue_name = queue_name

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cpu is not None:
            result['cpu'] = self.cpu

        if self.enable_auto_scaling is not None:
            result['enableAutoScaling'] = self.enable_auto_scaling

        if self.gpu_spec is not None:
            result['gpuSpec'] = self.gpu_spec

        if self.idle_timeout_seconds is not None:
            result['idleTimeoutSeconds'] = self.idle_timeout_seconds

        if self.memory is not None:
            result['memory'] = self.memory

        if self.queue_name is not None:
            result['queueName'] = self.queue_name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('cpu') is not None:
            self.cpu = m.get('cpu')

        if m.get('enableAutoScaling') is not None:
            self.enable_auto_scaling = m.get('enableAutoScaling')

        if m.get('gpuSpec') is not None:
            self.gpu_spec = m.get('gpuSpec')

        if m.get('idleTimeoutSeconds') is not None:
            self.idle_timeout_seconds = m.get('idleTimeoutSeconds')

        if m.get('memory') is not None:
            self.memory = m.get('memory')

        if m.get('queueName') is not None:
            self.queue_name = m.get('queueName')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class ListLivyComputeTokenResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.ListLivyComputeTokenResponseBodyData = None,
        message: str = None,
        request_id: str = None,
    ):
        self.code = code
        self.data = data
        self.message = message
        self.request_id = request_id

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['code'] = self.code

        if self.data is not None:
            result['data'] = self.data.to_map()

        if self.message is not None:
            result['message'] = self.message

        if self.request_id is not None:
            result['requestId'] = self.request_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('code') is not None:
            self.code = m.get('code')

        if m.get('data') is not None:
            temp_model = main_models.ListLivyComputeTokenResponseBodyData()
            self.data = temp_model.from_map(m.get('data'))

        if m.get('message') is not None:
            self.message = m.get('message')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        return self

class ListLivyComputeTokenResponseBodyData(DaraModel):
    def __init__(
        self,
        tokens: List[main_models.ListLivyComputeTokenResponseBodyDataTokens] = None,
    ):
        self.tokens = tokens

    def validate(self):
        if self.tokens:
            for v1 in self.tokens:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['tokens'] = []
        if self.tokens is not None:
            for k1 in self.tokens:
                result['tokens'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.tokens = []
        if m.get('tokens') is not None:
            for k1 in m.get('tokens'):
                temp_model = main_models.ListLivyComputeTokenResponseBodyDataTokens()
                self.tokens.append(temp_model.from_map(k1))

        return self

class ListLivyComputeTokenResponseBodyDataTokens(DaraModel):
    def __init__(
        self,
        create_time: int = None,
        createdby: str = None,
        expire_time: int = None,
        last_used_time: int = None,
        name: str = None,
        token: str = None,
        token_id: str = None,
    ):
        self.create_time = create_time
        self.createdby = createdby
        self.expire_time = expire_time
        self.last_used_time = last_used_time
        self.name = name
        self.token = token
        # Token ID。
        self.token_id = token_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.create_time is not None:
            result['createTime'] = self.create_time

        if self.createdby is not None:
            result['createdby'] = self.createdby

        if self.expire_time is not None:
            result['expireTime'] = self.expire_time

        if self.last_used_time is not None:
            result['lastUsedTime'] = self.last_used_time

        if self.name is not None:
            result['name'] = self.name

        if self.token is not None:
            result['token'] = self.token

        if self.token_id is not None:
            result['tokenId'] = self.token_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('createTime') is not None:
            self.create_time = m.get('createTime')

        if m.get('createdby') is not None:
            self.createdby = m.get('createdby')

        if m.get('expireTime') is not None:
            self.expire_time = m.get('expireTime')

        if m.get('lastUsedTime') is not None:
            self.last_used_time = m.get('lastUsedTime')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('token') is not None:
            self.token = m.get('token')

        if m.get('tokenId') is not None:
            self.token_id = m.get('tokenId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ReleaseVersionImage(DaraModel):
    def __init__(
        self,
        cpu_architecture: str = None,
        image_id: str = None,
        runtime_engine_type: str = None,
    ):
        self.cpu_architecture = cpu_architecture
        self.image_id = image_id
        self.runtime_engine_type = runtime_engine_type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cpu_architecture is not None:
            result['cpuArchitecture'] = self.cpu_architecture

        if self.image_id is not None:
            result['imageId'] = self.image_id

        if self.runtime_engine_type is not None:
            result['runtimeEngineType'] = self.runtime_engine_type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('cpuArchitecture') is not None:
            self.cpu_architecture = m.get('cpuArchitecture')

        if m.get('imageId') is not None:
            self.image_id = m.get('imageId')

        if m.get('runtimeEngineType') is not None:
            self.runtime_engine_type = m.get('runtimeEngineType')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class SqlOutput(DaraModel):
    def __init__(
        self,
        rows: List[main_models.SqlOutputRows] = None,
        schema: main_models.SqlOutputSchema = None,
    ):
        self.rows = rows
        self.schema = schema

    def validate(self):
        if self.rows:
            for v1 in self.rows:
                 if v1:
                    v1.validate()
        if self.schema:
            self.schema.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['rows'] = []
        if self.rows is not None:
            for k1 in self.rows:
                result['rows'].append(k1.to_map() if k1 else None)

        if self.schema is not None:
            result['schema'] = self.schema.to_map()

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.rows = []
        if m.get('rows') is not None:
            for k1 in m.get('rows'):
                temp_model = main_models.SqlOutputRows()
                self.rows.append(temp_model.from_map(k1))

        if m.get('schema') is not None:
            temp_model = main_models.SqlOutputSchema()
            self.schema = temp_model.from_map(m.get('schema'))

        return self

class SqlOutputSchema(DaraModel):
    def __init__(
        self,
        fields: List[main_models.SqlOutputSchemaFields] = None,
    ):
        self.fields = fields

    def validate(self):
        if self.fields:
            for v1 in self.fields:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['fields'] = []
        if self.fields is not None:
            for k1 in self.fields:
                result['fields'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.fields = []
        if m.get('fields') is not None:
            for k1 in m.get('fields'):
                temp_model = main_models.SqlOutputSchemaFields()
                self.fields.append(temp_model.from_map(k1))

        return self

class SqlOutputSchemaFields(DaraModel):
    def __init__(
        self,
        name: str = None,
        nullable: bool = None,
        type: str = None,
    ):
        self.name = name
        self.nullable = nullable
        self.type = type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.name is not None:
            result['name'] = self.name

        if self.nullable is not None:
            result['nullable'] = self.nullable

        if self.type is not None:
            result['type'] = self.type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('nullable') is not None:
            self.nullable = m.get('nullable')

        if m.get('type') is not None:
            self.type = m.get('type')

        return self

class SqlOutputRows(DaraModel):
    def __init__(
        self,
        values: List[str] = None,
    ):
        self.values = values

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.values is not None:
            result['values'] = self.values

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('values') is not None:
            self.values = m.get('values')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class ListReleaseVersionsResponseBody(DaraModel):
    def __init__(
        self,
        max_results: int = None,
        next_token: str = None,
        release_versions: List[main_models.ListReleaseVersionsResponseBodyReleaseVersions] = None,
        request_id: str = None,
        total_count: int = None,
    ):
        # The maximum number of entries returned.
        self.max_results = max_results
        # A pagination token. It can be used in the next request to retrieve a new page of results.
        self.next_token = next_token
        # The versions.
        self.release_versions = release_versions
        # The request ID.
        self.request_id = request_id
        # The total number of entries returned.
        self.total_count = total_count

    def validate(self):
        if self.release_versions:
            for v1 in self.release_versions:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.max_results is not None:
            result['maxResults'] = self.max_results

        if self.next_token is not None:
            result['nextToken'] = self.next_token

        result['releaseVersions'] = []
        if self.release_versions is not None:
            for k1 in self.release_versions:
                result['releaseVersions'].append(k1.to_map() if k1 else None)

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.total_count is not None:
            result['totalCount'] = self.total_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('maxResults') is not None:
            self.max_results = m.get('maxResults')

        if m.get('nextToken') is not None:
            self.next_token = m.get('nextToken')

        self.release_versions = []
        if m.get('releaseVersions') is not None:
            for k1 in m.get('releaseVersions'):
                temp_model = main_models.ListReleaseVersionsResponseBodyReleaseVersions()
                self.release_versions.append(temp_model.from_map(k1))

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('totalCount') is not None:
            self.total_count = m.get('totalCount')

        return self

class ListReleaseVersionsResponseBodyReleaseVersions(DaraModel):
    def __init__(
        self,
        community_version: str = None,
        cpu_architectures: List[str] = None,
        display_release_version: str = None,
        fusion: bool = None,
        gmt_create: int = None,
        iaas_type: str = None,
        release_version: str = None,
        scala_version: str = None,
        state: str = None,
        type: str = None,
    ):
        # The version number of open source Spark.
        self.community_version = community_version
        # The CPU architectures.
        self.cpu_architectures = cpu_architectures
        # The version number.
        self.display_release_version = display_release_version
        # Indicates whether the Fusion engine is used for acceleration.
        self.fusion = fusion
        # The creation time.
        self.gmt_create = gmt_create
        # The type of the Infrastructure as a Service (IaaS) layer.
        self.iaas_type = iaas_type
        # The version number.
        self.release_version = release_version
        # The version of Scala.
        self.scala_version = scala_version
        # The status of the version.
        self.state = state
        # The type of the version.
        self.type = type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.community_version is not None:
            result['communityVersion'] = self.community_version

        if self.cpu_architectures is not None:
            result['cpuArchitectures'] = self.cpu_architectures

        if self.display_release_version is not None:
            result['displayReleaseVersion'] = self.display_release_version

        if self.fusion is not None:
            result['fusion'] = self.fusion

        if self.gmt_create is not None:
            result['gmtCreate'] = self.gmt_create

        if self.iaas_type is not None:
            result['iaasType'] = self.iaas_type

        if self.release_version is not None:
            result['releaseVersion'] = self.release_version

        if self.scala_version is not None:
            result['scalaVersion'] = self.scala_version

        if self.state is not None:
            result['state'] = self.state

        if self.type is not None:
            result['type'] = self.type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('communityVersion') is not None:
            self.community_version = m.get('communityVersion')

        if m.get('cpuArchitectures') is not None:
            self.cpu_architectures = m.get('cpuArchitectures')

        if m.get('displayReleaseVersion') is not None:
            self.display_release_version = m.get('displayReleaseVersion')

        if m.get('fusion') is not None:
            self.fusion = m.get('fusion')

        if m.get('gmtCreate') is not None:
            self.gmt_create = m.get('gmtCreate')

        if m.get('iaasType') is not None:
            self.iaas_type = m.get('iaasType')

        if m.get('releaseVersion') is not None:
            self.release_version = m.get('releaseVersion')

        if m.get('scalaVersion') is not None:
            self.scala_version = m.get('scalaVersion')

        if m.get('state') is not None:
            self.state = m.get('state')

        if m.get('type') is not None:
            self.type = m.get('type')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class CreateLivyComputeRequest(DaraModel):
    def __init__(
        self,
        auth_type: str = None,
        auto_start_configuration: main_models.CreateLivyComputeRequestAutoStartConfiguration = None,
        auto_stop_configuration: main_models.CreateLivyComputeRequestAutoStopConfiguration = None,
        cpu_limit: str = None,
        display_release_version: str = None,
        enable_public: bool = None,
        environment_id: str = None,
        fusion: bool = None,
        livy_server_conf: str = None,
        livy_version: str = None,
        memory_limit: str = None,
        name: str = None,
        network_name: str = None,
        queue_name: str = None,
        release_version: str = None,
        region_id: str = None,
    ):
        self.auth_type = auth_type
        self.auto_start_configuration = auto_start_configuration
        self.auto_stop_configuration = auto_stop_configuration
        self.cpu_limit = cpu_limit
        self.display_release_version = display_release_version
        self.enable_public = enable_public
        self.environment_id = environment_id
        self.fusion = fusion
        self.livy_server_conf = livy_server_conf
        self.livy_version = livy_version
        self.memory_limit = memory_limit
        self.name = name
        self.network_name = network_name
        self.queue_name = queue_name
        self.release_version = release_version
        self.region_id = region_id

    def validate(self):
        if self.auto_start_configuration:
            self.auto_start_configuration.validate()
        if self.auto_stop_configuration:
            self.auto_stop_configuration.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.auth_type is not None:
            result['authType'] = self.auth_type

        if self.auto_start_configuration is not None:
            result['autoStartConfiguration'] = self.auto_start_configuration.to_map()

        if self.auto_stop_configuration is not None:
            result['autoStopConfiguration'] = self.auto_stop_configuration.to_map()

        if self.cpu_limit is not None:
            result['cpuLimit'] = self.cpu_limit

        if self.display_release_version is not None:
            result['displayReleaseVersion'] = self.display_release_version

        if self.enable_public is not None:
            result['enablePublic'] = self.enable_public

        if self.environment_id is not None:
            result['environmentId'] = self.environment_id

        if self.fusion is not None:
            result['fusion'] = self.fusion

        if self.livy_server_conf is not None:
            result['livyServerConf'] = self.livy_server_conf

        if self.livy_version is not None:
            result['livyVersion'] = self.livy_version

        if self.memory_limit is not None:
            result['memoryLimit'] = self.memory_limit

        if self.name is not None:
            result['name'] = self.name

        if self.network_name is not None:
            result['networkName'] = self.network_name

        if self.queue_name is not None:
            result['queueName'] = self.queue_name

        if self.release_version is not None:
            result['releaseVersion'] = self.release_version

        if self.region_id is not None:
            result['regionId'] = self.region_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('authType') is not None:
            self.auth_type = m.get('authType')

        if m.get('autoStartConfiguration') is not None:
            temp_model = main_models.CreateLivyComputeRequestAutoStartConfiguration()
            self.auto_start_configuration = temp_model.from_map(m.get('autoStartConfiguration'))

        if m.get('autoStopConfiguration') is not None:
            temp_model = main_models.CreateLivyComputeRequestAutoStopConfiguration()
            self.auto_stop_configuration = temp_model.from_map(m.get('autoStopConfiguration'))

        if m.get('cpuLimit') is not None:
            self.cpu_limit = m.get('cpuLimit')

        if m.get('displayReleaseVersion') is not None:
            self.display_release_version = m.get('displayReleaseVersion')

        if m.get('enablePublic') is not None:
            self.enable_public = m.get('enablePublic')

        if m.get('environmentId') is not None:
            self.environment_id = m.get('environmentId')

        if m.get('fusion') is not None:
            self.fusion = m.get('fusion')

        if m.get('livyServerConf') is not None:
            self.livy_server_conf = m.get('livyServerConf')

        if m.get('livyVersion') is not None:
            self.livy_version = m.get('livyVersion')

        if m.get('memoryLimit') is not None:
            self.memory_limit = m.get('memoryLimit')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('networkName') is not None:
            self.network_name = m.get('networkName')

        if m.get('queueName') is not None:
            self.queue_name = m.get('queueName')

        if m.get('releaseVersion') is not None:
            self.release_version = m.get('releaseVersion')

        if m.get('regionId') is not None:
            self.region_id = m.get('regionId')

        return self

class CreateLivyComputeRequestAutoStopConfiguration(DaraModel):
    def __init__(
        self,
        enable: bool = None,
        idle_timeout_minutes: int = None,
    ):
        self.enable = enable
        self.idle_timeout_minutes = idle_timeout_minutes

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.enable is not None:
            result['enable'] = self.enable

        if self.idle_timeout_minutes is not None:
            result['idleTimeoutMinutes'] = self.idle_timeout_minutes

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('enable') is not None:
            self.enable = m.get('enable')

        if m.get('idleTimeoutMinutes') is not None:
            self.idle_timeout_minutes = m.get('idleTimeoutMinutes')

        return self

class CreateLivyComputeRequestAutoStartConfiguration(DaraModel):
    def __init__(
        self,
        enable: bool = None,
    ):
        self.enable = enable

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.enable is not None:
            result['enable'] = self.enable

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('enable') is not None:
            self.enable = m.get('enable')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class CreateSqlStatementRequest(DaraModel):
    def __init__(
        self,
        code_content: str = None,
        default_catalog: str = None,
        default_database: str = None,
        limit: int = None,
        sql_compute_id: str = None,
        task_biz_id: str = None,
        region_id: str = None,
    ):
        # The SQL code. You can specify one or more SQL statements.
        self.code_content = code_content
        # The default Data Lake Formation (DLF) catalog ID.
        self.default_catalog = default_catalog
        # The name of the default database.
        self.default_database = default_database
        # The maximum number of entries to return. Valid values: 1 to 10000.
        self.limit = limit
        # The SQL session ID. You can create an SQL session in the workspace created in EMR Serverless Spark.
        self.sql_compute_id = sql_compute_id
        self.task_biz_id = task_biz_id
        # The region ID.
        self.region_id = region_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code_content is not None:
            result['codeContent'] = self.code_content

        if self.default_catalog is not None:
            result['defaultCatalog'] = self.default_catalog

        if self.default_database is not None:
            result['defaultDatabase'] = self.default_database

        if self.limit is not None:
            result['limit'] = self.limit

        if self.sql_compute_id is not None:
            result['sqlComputeId'] = self.sql_compute_id

        if self.task_biz_id is not None:
            result['taskBizId'] = self.task_biz_id

        if self.region_id is not None:
            result['regionId'] = self.region_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('codeContent') is not None:
            self.code_content = m.get('codeContent')

        if m.get('defaultCatalog') is not None:
            self.default_catalog = m.get('defaultCatalog')

        if m.get('defaultDatabase') is not None:
            self.default_database = m.get('defaultDatabase')

        if m.get('limit') is not None:
            self.limit = m.get('limit')

        if m.get('sqlComputeId') is not None:
            self.sql_compute_id = m.get('sqlComputeId')

        if m.get('taskBizId') is not None:
            self.task_biz_id = m.get('taskBizId')

        if m.get('regionId') is not None:
            self.region_id = m.get('regionId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class StartJobRunRequest(DaraModel):
    def __init__(
        self,
        client_token: str = None,
        code_type: str = None,
        configuration_overrides: main_models.StartJobRunRequestConfigurationOverrides = None,
        display_release_version: str = None,
        execution_timeout_seconds: int = None,
        fusion: bool = None,
        job_driver: main_models.JobDriver = None,
        job_id: str = None,
        name: str = None,
        release_version: str = None,
        resource_queue_id: str = None,
        tags: List[main_models.Tag] = None,
        region_id: str = None,
    ):
        # The client token that is used to ensure the idempotence of the request.
        self.client_token = client_token
        # The code type of the job. Valid values:
        # 
        # *   SQL
        # *   JAR
        # *   PYTHON
        self.code_type = code_type
        # The advanced configurations of Spark.
        self.configuration_overrides = configuration_overrides
        # The version of the Spark engine.
        self.display_release_version = display_release_version
        # The timeout period of the job.
        self.execution_timeout_seconds = execution_timeout_seconds
        # Specifies whether to enable Fusion engine for acceleration.
        self.fusion = fusion
        # The information about Spark Driver.
        self.job_driver = job_driver
        # The job ID.
        self.job_id = job_id
        # The name of the job.
        self.name = name
        # The version number of Spark.
        self.release_version = release_version
        # The name of the resource queue on which the Spark job runs.
        self.resource_queue_id = resource_queue_id
        # The tags of the job.
        self.tags = tags
        # The region ID.
        self.region_id = region_id

    def validate(self):
        if self.configuration_overrides:
            self.configuration_overrides.validate()
        if self.job_driver:
            self.job_driver.validate()
        if self.tags:
            for v1 in self.tags:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.client_token is not None:
            result['clientToken'] = self.client_token

        if self.code_type is not None:
            result['codeType'] = self.code_type

        if self.configuration_overrides is not None:
            result['configurationOverrides'] = self.configuration_overrides.to_map()

        if self.display_release_version is not None:
            result['displayReleaseVersion'] = self.display_release_version

        if self.execution_timeout_seconds is not None:
            result['executionTimeoutSeconds'] = self.execution_timeout_seconds

        if self.fusion is not None:
            result['fusion'] = self.fusion

        if self.job_driver is not None:
            result['jobDriver'] = self.job_driver.to_map()

        if self.job_id is not None:
            result['jobId'] = self.job_id

        if self.name is not None:
            result['name'] = self.name

        if self.release_version is not None:
            result['releaseVersion'] = self.release_version

        if self.resource_queue_id is not None:
            result['resourceQueueId'] = self.resource_queue_id

        result['tags'] = []
        if self.tags is not None:
            for k1 in self.tags:
                result['tags'].append(k1.to_map() if k1 else None)

        if self.region_id is not None:
            result['regionId'] = self.region_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('clientToken') is not None:
            self.client_token = m.get('clientToken')

        if m.get('codeType') is not None:
            self.code_type = m.get('codeType')

        if m.get('configurationOverrides') is not None:
            temp_model = main_models.StartJobRunRequestConfigurationOverrides()
            self.configuration_overrides = temp_model.from_map(m.get('configurationOverrides'))

        if m.get('displayReleaseVersion') is not None:
            self.display_release_version = m.get('displayReleaseVersion')

        if m.get('executionTimeoutSeconds') is not None:
            self.execution_timeout_seconds = m.get('executionTimeoutSeconds')

        if m.get('fusion') is not None:
            self.fusion = m.get('fusion')

        if m.get('jobDriver') is not None:
            temp_model = main_models.JobDriver()
            self.job_driver = temp_model.from_map(m.get('jobDriver'))

        if m.get('jobId') is not None:
            self.job_id = m.get('jobId')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('releaseVersion') is not None:
            self.release_version = m.get('releaseVersion')

        if m.get('resourceQueueId') is not None:
            self.resource_queue_id = m.get('resourceQueueId')

        self.tags = []
        if m.get('tags') is not None:
            for k1 in m.get('tags'):
                temp_model = main_models.Tag()
                self.tags.append(temp_model.from_map(k1))

        if m.get('regionId') is not None:
            self.region_id = m.get('regionId')

        return self

class StartJobRunRequestConfigurationOverrides(DaraModel):
    def __init__(
        self,
        configurations: List[main_models.StartJobRunRequestConfigurationOverridesConfigurations] = None,
    ):
        # The SparkConf objects.
        self.configurations = configurations

    def validate(self):
        if self.configurations:
            for v1 in self.configurations:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['configurations'] = []
        if self.configurations is not None:
            for k1 in self.configurations:
                result['configurations'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.configurations = []
        if m.get('configurations') is not None:
            for k1 in m.get('configurations'):
                temp_model = main_models.StartJobRunRequestConfigurationOverridesConfigurations()
                self.configurations.append(temp_model.from_map(k1))

        return self

class StartJobRunRequestConfigurationOverridesConfigurations(DaraModel):
    def __init__(
        self,
        config_file_name: str = None,
        config_item_key: str = None,
        config_item_value: str = None,
    ):
        # The configuration file of SparkConf.
        self.config_file_name = config_file_name
        # The key of SparkConf.
        self.config_item_key = config_item_key
        # The value of SparkConf.
        self.config_item_value = config_item_value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.config_file_name is not None:
            result['configFileName'] = self.config_file_name

        if self.config_item_key is not None:
            result['configItemKey'] = self.config_item_key

        if self.config_item_value is not None:
            result['configItemValue'] = self.config_item_value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('configFileName') is not None:
            self.config_file_name = m.get('configFileName')

        if m.get('configItemKey') is not None:
            self.config_item_key = m.get('configItemKey')

        if m.get('configItemValue') is not None:
            self.config_item_value = m.get('configItemValue')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class UpdateKyuubiServiceRequest(DaraModel):
    def __init__(
        self,
        compute_instance: str = None,
        kyuubi_configs: str = None,
        kyuubi_release_version: str = None,
        name: str = None,
        public_endpoint_enabled: bool = None,
        queue: str = None,
        release_version: str = None,
        replica: int = None,
        restart: bool = None,
        spark_configs: str = None,
    ):
        self.compute_instance = compute_instance
        self.kyuubi_configs = kyuubi_configs
        self.kyuubi_release_version = kyuubi_release_version
        self.name = name
        self.public_endpoint_enabled = public_endpoint_enabled
        self.queue = queue
        self.release_version = release_version
        self.replica = replica
        self.restart = restart
        self.spark_configs = spark_configs

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.compute_instance is not None:
            result['computeInstance'] = self.compute_instance

        if self.kyuubi_configs is not None:
            result['kyuubiConfigs'] = self.kyuubi_configs

        if self.kyuubi_release_version is not None:
            result['kyuubiReleaseVersion'] = self.kyuubi_release_version

        if self.name is not None:
            result['name'] = self.name

        if self.public_endpoint_enabled is not None:
            result['publicEndpointEnabled'] = self.public_endpoint_enabled

        if self.queue is not None:
            result['queue'] = self.queue

        if self.release_version is not None:
            result['releaseVersion'] = self.release_version

        if self.replica is not None:
            result['replica'] = self.replica

        if self.restart is not None:
            result['restart'] = self.restart

        if self.spark_configs is not None:
            result['sparkConfigs'] = self.spark_configs

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('computeInstance') is not None:
            self.compute_instance = m.get('computeInstance')

        if m.get('kyuubiConfigs') is not None:
            self.kyuubi_configs = m.get('kyuubiConfigs')

        if m.get('kyuubiReleaseVersion') is not None:
            self.kyuubi_release_version = m.get('kyuubiReleaseVersion')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('publicEndpointEnabled') is not None:
            self.public_endpoint_enabled = m.get('publicEndpointEnabled')

        if m.get('queue') is not None:
            self.queue = m.get('queue')

        if m.get('releaseVersion') is not None:
            self.release_version = m.get('releaseVersion')

        if m.get('replica') is not None:
            self.replica = m.get('replica')

        if m.get('restart') is not None:
            self.restart = m.get('restart')

        if m.get('sparkConfigs') is not None:
            self.spark_configs = m.get('sparkConfigs')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class ListJobExecutorsResponseBody(DaraModel):
    def __init__(
        self,
        exexutors: List[main_models.ListJobExecutorsResponseBodyExexutors] = None,
        max_results: int = None,
        next_token: str = None,
        request_id: str = None,
        total_count: int = None,
    ):
        self.exexutors = exexutors
        self.max_results = max_results
        self.next_token = next_token
        # Id of the request
        self.request_id = request_id
        self.total_count = total_count

    def validate(self):
        if self.exexutors:
            for v1 in self.exexutors:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['exexutors'] = []
        if self.exexutors is not None:
            for k1 in self.exexutors:
                result['exexutors'].append(k1.to_map() if k1 else None)

        if self.max_results is not None:
            result['maxResults'] = self.max_results

        if self.next_token is not None:
            result['nextToken'] = self.next_token

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.total_count is not None:
            result['totalCount'] = self.total_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.exexutors = []
        if m.get('exexutors') is not None:
            for k1 in m.get('exexutors'):
                temp_model = main_models.ListJobExecutorsResponseBodyExexutors()
                self.exexutors.append(temp_model.from_map(k1))

        if m.get('maxResults') is not None:
            self.max_results = m.get('maxResults')

        if m.get('nextToken') is not None:
            self.next_token = m.get('nextToken')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('totalCount') is not None:
            self.total_count = m.get('totalCount')

        return self

class ListJobExecutorsResponseBodyExexutors(DaraModel):
    def __init__(
        self,
        active_tasks: int = None,
        add_time: int = None,
        completed_tasks: int = None,
        disk_used: int = None,
        executor_id: str = None,
        executor_type: str = None,
        failed_tasks: int = None,
        host_port: str = None,
        job_run_id: str = None,
        max_memory: int = None,
        memory_used: int = None,
        rdd_blocks: int = None,
        status: str = None,
        total_cores: int = None,
        total_duration: int = None,
        total_gctime: int = None,
        total_input_bytes: int = None,
        total_shuffle_read: int = None,
        total_shuffle_write: int = None,
        total_tasks: int = None,
        workspace_id: str = None,
    ):
        self.active_tasks = active_tasks
        self.add_time = add_time
        self.completed_tasks = completed_tasks
        self.disk_used = disk_used
        self.executor_id = executor_id
        self.executor_type = executor_type
        self.failed_tasks = failed_tasks
        self.host_port = host_port
        self.job_run_id = job_run_id
        self.max_memory = max_memory
        self.memory_used = memory_used
        self.rdd_blocks = rdd_blocks
        self.status = status
        self.total_cores = total_cores
        self.total_duration = total_duration
        self.total_gctime = total_gctime
        self.total_input_bytes = total_input_bytes
        self.total_shuffle_read = total_shuffle_read
        self.total_shuffle_write = total_shuffle_write
        self.total_tasks = total_tasks
        self.workspace_id = workspace_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.active_tasks is not None:
            result['activeTasks'] = self.active_tasks

        if self.add_time is not None:
            result['addTime'] = self.add_time

        if self.completed_tasks is not None:
            result['completedTasks'] = self.completed_tasks

        if self.disk_used is not None:
            result['diskUsed'] = self.disk_used

        if self.executor_id is not None:
            result['executorId'] = self.executor_id

        if self.executor_type is not None:
            result['executorType'] = self.executor_type

        if self.failed_tasks is not None:
            result['failedTasks'] = self.failed_tasks

        if self.host_port is not None:
            result['hostPort'] = self.host_port

        if self.job_run_id is not None:
            result['jobRunId'] = self.job_run_id

        if self.max_memory is not None:
            result['maxMemory'] = self.max_memory

        if self.memory_used is not None:
            result['memoryUsed'] = self.memory_used

        if self.rdd_blocks is not None:
            result['rddBlocks'] = self.rdd_blocks

        if self.status is not None:
            result['status'] = self.status

        if self.total_cores is not None:
            result['totalCores'] = self.total_cores

        if self.total_duration is not None:
            result['totalDuration'] = self.total_duration

        if self.total_gctime is not None:
            result['totalGCTime'] = self.total_gctime

        if self.total_input_bytes is not None:
            result['totalInputBytes'] = self.total_input_bytes

        if self.total_shuffle_read is not None:
            result['totalShuffleRead'] = self.total_shuffle_read

        if self.total_shuffle_write is not None:
            result['totalShuffleWrite'] = self.total_shuffle_write

        if self.total_tasks is not None:
            result['totalTasks'] = self.total_tasks

        if self.workspace_id is not None:
            result['workspaceId'] = self.workspace_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('activeTasks') is not None:
            self.active_tasks = m.get('activeTasks')

        if m.get('addTime') is not None:
            self.add_time = m.get('addTime')

        if m.get('completedTasks') is not None:
            self.completed_tasks = m.get('completedTasks')

        if m.get('diskUsed') is not None:
            self.disk_used = m.get('diskUsed')

        if m.get('executorId') is not None:
            self.executor_id = m.get('executorId')

        if m.get('executorType') is not None:
            self.executor_type = m.get('executorType')

        if m.get('failedTasks') is not None:
            self.failed_tasks = m.get('failedTasks')

        if m.get('hostPort') is not None:
            self.host_port = m.get('hostPort')

        if m.get('jobRunId') is not None:
            self.job_run_id = m.get('jobRunId')

        if m.get('maxMemory') is not None:
            self.max_memory = m.get('maxMemory')

        if m.get('memoryUsed') is not None:
            self.memory_used = m.get('memoryUsed')

        if m.get('rddBlocks') is not None:
            self.rdd_blocks = m.get('rddBlocks')

        if m.get('status') is not None:
            self.status = m.get('status')

        if m.get('totalCores') is not None:
            self.total_cores = m.get('totalCores')

        if m.get('totalDuration') is not None:
            self.total_duration = m.get('totalDuration')

        if m.get('totalGCTime') is not None:
            self.total_gctime = m.get('totalGCTime')

        if m.get('totalInputBytes') is not None:
            self.total_input_bytes = m.get('totalInputBytes')

        if m.get('totalShuffleRead') is not None:
            self.total_shuffle_read = m.get('totalShuffleRead')

        if m.get('totalShuffleWrite') is not None:
            self.total_shuffle_write = m.get('totalShuffleWrite')

        if m.get('totalTasks') is not None:
            self.total_tasks = m.get('totalTasks')

        if m.get('workspaceId') is not None:
            self.workspace_id = m.get('workspaceId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class ListWorkspaceQueuesResponseBody(DaraModel):
    def __init__(
        self,
        max_results: int = None,
        next_token: str = None,
        queues: List[main_models.ListWorkspaceQueuesResponseBodyQueues] = None,
        request_id: str = None,
        total_count: int = None,
    ):
        # The maximum number of entries returned.
        self.max_results = max_results
        # A pagination token. It can be used in the next request to retrieve a new page of results.
        self.next_token = next_token
        # The list of queues.
        self.queues = queues
        # The request ID.
        self.request_id = request_id
        # The total number of entries returned.
        self.total_count = total_count

    def validate(self):
        if self.queues:
            for v1 in self.queues:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.max_results is not None:
            result['maxResults'] = self.max_results

        if self.next_token is not None:
            result['nextToken'] = self.next_token

        result['queues'] = []
        if self.queues is not None:
            for k1 in self.queues:
                result['queues'].append(k1.to_map() if k1 else None)

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.total_count is not None:
            result['totalCount'] = self.total_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('maxResults') is not None:
            self.max_results = m.get('maxResults')

        if m.get('nextToken') is not None:
            self.next_token = m.get('nextToken')

        self.queues = []
        if m.get('queues') is not None:
            for k1 in m.get('queues'):
                temp_model = main_models.ListWorkspaceQueuesResponseBodyQueues()
                self.queues.append(temp_model.from_map(k1))

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('totalCount') is not None:
            self.total_count = m.get('totalCount')

        return self

class ListWorkspaceQueuesResponseBodyQueues(DaraModel):
    def __init__(
        self,
        allow_actions: List[main_models.ListWorkspaceQueuesResponseBodyQueuesAllowActions] = None,
        create_time: int = None,
        creator: str = None,
        environments: List[str] = None,
        gpu_spec: List[str] = None,
        max_resource: str = None,
        min_resource: str = None,
        payment_type: str = None,
        preheat: bool = None,
        properties: str = None,
        queue_category: str = None,
        queue_name: str = None,
        queue_scope: str = None,
        queue_status: str = None,
        queue_type: str = None,
        region_id: str = None,
        used_resource: str = None,
        workspace_id: str = None,
    ):
        # The operations allowed for the queue.
        self.allow_actions = allow_actions
        # The time when the workspace was created.
        self.create_time = create_time
        # The ID of the user who created the queue.
        self.creator = creator
        # The environment types of the queue.
        self.environments = environments
        self.gpu_spec = gpu_spec
        # The maximum capacity of resources that can be used in the queue.
        self.max_resource = max_resource
        # The minimum capacity of resources that can be used in the queue.
        self.min_resource = min_resource
        # The billing method. Valid values:
        # 
        # *   PayAsYouGo
        # *   Pre
        self.payment_type = payment_type
        self.preheat = preheat
        # The queue label.
        self.properties = properties
        self.queue_category = queue_category
        # The name of the queue.
        self.queue_name = queue_name
        # The queue architecture.
        self.queue_scope = queue_scope
        # The status of the queue.
        self.queue_status = queue_status
        # The type of the queue. Valid values:
        # 
        # *   instance
        # *   instanceChildren
        self.queue_type = queue_type
        # The region ID.
        self.region_id = region_id
        # The capacity of resources that are used in the queue.
        self.used_resource = used_resource
        # The workspace ID.
        self.workspace_id = workspace_id

    def validate(self):
        if self.allow_actions:
            for v1 in self.allow_actions:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['allowActions'] = []
        if self.allow_actions is not None:
            for k1 in self.allow_actions:
                result['allowActions'].append(k1.to_map() if k1 else None)

        if self.create_time is not None:
            result['createTime'] = self.create_time

        if self.creator is not None:
            result['creator'] = self.creator

        if self.environments is not None:
            result['environments'] = self.environments

        if self.gpu_spec is not None:
            result['gpuSpec'] = self.gpu_spec

        if self.max_resource is not None:
            result['maxResource'] = self.max_resource

        if self.min_resource is not None:
            result['minResource'] = self.min_resource

        if self.payment_type is not None:
            result['paymentType'] = self.payment_type

        if self.preheat is not None:
            result['preheat'] = self.preheat

        if self.properties is not None:
            result['properties'] = self.properties

        if self.queue_category is not None:
            result['queueCategory'] = self.queue_category

        if self.queue_name is not None:
            result['queueName'] = self.queue_name

        if self.queue_scope is not None:
            result['queueScope'] = self.queue_scope

        if self.queue_status is not None:
            result['queueStatus'] = self.queue_status

        if self.queue_type is not None:
            result['queueType'] = self.queue_type

        if self.region_id is not None:
            result['regionId'] = self.region_id

        if self.used_resource is not None:
            result['usedResource'] = self.used_resource

        if self.workspace_id is not None:
            result['workspaceId'] = self.workspace_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.allow_actions = []
        if m.get('allowActions') is not None:
            for k1 in m.get('allowActions'):
                temp_model = main_models.ListWorkspaceQueuesResponseBodyQueuesAllowActions()
                self.allow_actions.append(temp_model.from_map(k1))

        if m.get('createTime') is not None:
            self.create_time = m.get('createTime')

        if m.get('creator') is not None:
            self.creator = m.get('creator')

        if m.get('environments') is not None:
            self.environments = m.get('environments')

        if m.get('gpuSpec') is not None:
            self.gpu_spec = m.get('gpuSpec')

        if m.get('maxResource') is not None:
            self.max_resource = m.get('maxResource')

        if m.get('minResource') is not None:
            self.min_resource = m.get('minResource')

        if m.get('paymentType') is not None:
            self.payment_type = m.get('paymentType')

        if m.get('preheat') is not None:
            self.preheat = m.get('preheat')

        if m.get('properties') is not None:
            self.properties = m.get('properties')

        if m.get('queueCategory') is not None:
            self.queue_category = m.get('queueCategory')

        if m.get('queueName') is not None:
            self.queue_name = m.get('queueName')

        if m.get('queueScope') is not None:
            self.queue_scope = m.get('queueScope')

        if m.get('queueStatus') is not None:
            self.queue_status = m.get('queueStatus')

        if m.get('queueType') is not None:
            self.queue_type = m.get('queueType')

        if m.get('regionId') is not None:
            self.region_id = m.get('regionId')

        if m.get('usedResource') is not None:
            self.used_resource = m.get('usedResource')

        if m.get('workspaceId') is not None:
            self.workspace_id = m.get('workspaceId')

        return self

class ListWorkspaceQueuesResponseBodyQueuesAllowActions(DaraModel):
    def __init__(
        self,
        action_arn: str = None,
        action_name: str = None,
        dependencies: List[str] = None,
        description: str = None,
        display_name: str = None,
    ):
        # The Alibaba Cloud Resource Name (ARN) of a behavior.
        self.action_arn = action_arn
        # The name of the permission.
        self.action_name = action_name
        # The dependencies of the operation.
        self.dependencies = dependencies
        # The description of the operation.
        self.description = description
        # The display name of the permission.
        self.display_name = display_name

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.action_arn is not None:
            result['actionArn'] = self.action_arn

        if self.action_name is not None:
            result['actionName'] = self.action_name

        if self.dependencies is not None:
            result['dependencies'] = self.dependencies

        if self.description is not None:
            result['description'] = self.description

        if self.display_name is not None:
            result['displayName'] = self.display_name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('actionArn') is not None:
            self.action_arn = m.get('actionArn')

        if m.get('actionName') is not None:
            self.action_name = m.get('actionName')

        if m.get('dependencies') is not None:
            self.dependencies = m.get('dependencies')

        if m.get('description') is not None:
            self.description = m.get('description')

        if m.get('displayName') is not None:
            self.display_name = m.get('displayName')

        return self

